@@ -1,16 +1,13 @@
 """Utility script to work with the CITATION.cff file"""
 import logging
 import subprocess
+from pathlib import Path
 import click
 from ruamel.yaml import YAML
-from pathlib import Path
 
 log = logging.getLogger(__name__)
 
-EXCLUDE_AUTHORS = [
-    "azure-pipelines[bot]",
-    "GitHub Actions"
-]
+EXCLUDE_AUTHORS = ["azure-pipelines[bot]", "GitHub Actions"]
 
 PATH = Path(__file__).parent.parent
 
