@@ -1,7 +1,7 @@
 r"""
 .. _point-spatial-model:
 
-Point Spatial Model
+Point spatial model
 ===================
 
 This model is a delta function centered in *lon_0* and *lat_0* parameters provided:
@@ -30,14 +30,18 @@ from gammapy.modeling.models import (
     SkyModel,
 )
 
-model = PointSpatialModel(lon_0="0.01 deg", lat_0="0.01 deg", frame="galactic",)
+model = PointSpatialModel(
+    lon_0="0.01 deg",
+    lat_0="0.01 deg",
+    frame="galactic",
+)
 
 geom = WcsGeom.create(
     skydir=SkyCoord("0d 0d", frame="galactic"), width=(1, 1), binsz=0.1
 )
 model.plot(geom=geom, add_cbar=True)
 
-#%%
+# %%
 # YAML representation
 # -------------------
 # Here is an example YAML file using the model:
