@@ -10,8 +10,8 @@ It is defined by the following equation:
 
 .. math::
     \phi(E) = phi_0 \cdot \begin{cases}
-                          \left( \frac{E}{E_0} \right)^{-\Gamma1} \rm{if} E < E_{break}\\
-                          \left( \frac{E}{E_0} \right)^{-\Gamma2} \rm{otherwise}
+                          \left( \frac{E}{E_{break}} \right)^{-\Gamma1} & \text{if } E < E_{break} \\
+                          \left( \frac{E}{E_{break}} \right)^{-\Gamma2} & \text{otherwise}
                          \end{cases}
     """
 
