@@ -1,8 +1,8 @@
 r"""
 .. _piecewise-norm-spectral:
 
-Piecewise  Norm Spectral Model
-==============================================
+Piecewise  norm spectral model
+==============================
 
 This model parametrises a piecewise spectral correction
 with a free norm parameter at each fixed energy node.
@@ -22,11 +22,12 @@ from gammapy.modeling.models import (
     SkyModel,
 )
 
-energy_range = [0.1, 100] * u.TeV
+energy_bounds = [0.1, 100] * u.TeV
 model = PiecewiseNormSpectralModel(
-    energy=[0.1, 1, 3, 10, 30, 100] * u.TeV, norms=[1, 3, 8, 10, 8, 2],
+    energy=[0.1, 1, 3, 10, 30, 100] * u.TeV,
+    norms=[1, 3, 8, 10, 8, 2],
 )
-model.plot(energy_range, flux_unit="")
+model.plot(energy_bounds, yunits=u.Unit(""))
 plt.grid(which="both")
 
 
