@@ -14,21 +14,19 @@ it only contains this:
 
 
 The Gammapy functionality is available for import from
-the following sub-packages (e.g. `gammapy.spectrum`):
+the following sub-packages (e.g. `gammapy.makers`):
 
 ::
 
  astro        --- Astrophysical source and population models
  catalog      --- Source catalog tools
- cube         --- Cube analysis
+ makers       --- Data reduction functionality
  data         --- Data and observation handling
- detect       --- Source detection tools
  irf          --- Instrument response functions (IRFs)
  maps         --- Sky map data structures
  modeling     --- Models and fitting
- spectrum     --- Spectrum estimation and modeling
+ estimators   --- High level flux estimation
  stats        --- Statistics tools
- time         --- Time handling and analysis
  utils        --- Utility functions and classes
 """
 
@@ -54,8 +52,8 @@ def song(karaoke=False):
     karaoke : bool
         Print lyrics to sing along.
     """
-    import webbrowser
     import sys
+    import webbrowser
 
     webbrowser.open("https://gammapy.org/gammapy_song.mp3")
 
