@@ -9,7 +9,7 @@ from astropy.coordinates import Angle
 from astropy.time import Time
 from astropy.units import Quantity
 import yaml
-from pydantic import BaseModel, FilePath
+from pydantic import BaseModel
 from pydantic.utils import deep_update
 from gammapy.makers import MapDatasetMaker
 from gammapy.utils.scripts import make_path, read_yaml
@@ -65,6 +65,16 @@ class FrameEnum(str, Enum):
     galactic = "galactic"
 
 
+class RequiredHDUEnum(str, Enum):
+    events = "events"
+    gti = "gti"
+    aeff = "aeff"
+    bkg = "bkg"
+    edisp = "edisp"
+    psf = "psf"
+    rad_max = "rad_max"
+
+
 class BackgroundMethodEnum(str, Enum):
     reflected = "reflected"
     fov = "fov_background"
@@ -106,9 +116,9 @@ class SkyCoordConfig(GammapyBaseConfig):
 
 
 class EnergyAxisConfig(GammapyBaseConfig):
-    min: EnergyType = "0.1 TeV"
-    max: EnergyType = "10 TeV"
-    nbins: int = 30
+    min: EnergyType = None
+    max: EnergyType = None
+    nbins: int = None
 
 
 class SpatialCircleConfig(GammapyBaseConfig):
@@ -119,8 +129,8 @@ class SpatialCircleConfig(GammapyBaseConfig):
 
 
 class EnergyRangeConfig(GammapyBaseConfig):
-    min: EnergyType = "0.1 TeV"
-    max: EnergyType = "10 TeV"
+    min: EnergyType = None
+    max: EnergyType = None
 
 
 class TimeRangeConfig(GammapyBaseConfig):
@@ -131,16 +141,29 @@ class TimeRangeConfig(GammapyBaseConfig):
 class FluxPointsConfig(GammapyBaseConfig):
     energy: EnergyAxisConfig = EnergyAxisConfig()
     source: str = "source"
-    parameters: dict = {}
+    parameters: dict = {"selection_optional": "all"}
+
+
+class LightCurveConfig(GammapyBaseConfig):
+    time_intervals: TimeRangeConfig = TimeRangeConfig()
+    energy_edges: EnergyAxisConfig = EnergyAxisConfig()
+    source: str = "source"
+    parameters: dict = {"selection_optional": "all"}
 
 
 class FitConfig(GammapyBaseConfig):
     fit_range: EnergyRangeConfig = EnergyRangeConfig()
 
 
+class ExcessMapConfig(GammapyBaseConfig):
+    correlation_radius: AngleType = "0.1 deg"
+    parameters: dict = {}
+    energy_edges: EnergyAxisConfig = EnergyAxisConfig()
+
+
 class BackgroundConfig(GammapyBaseConfig):
     method: BackgroundMethodEnum = None
-    exclusion: FilePath = None
+    exclusion: Path = None
     parameters: dict = {}
 
 
@@ -150,15 +173,17 @@ class SafeMaskConfig(GammapyBaseConfig):
 
 
 class EnergyAxesConfig(GammapyBaseConfig):
-    energy: EnergyAxisConfig = EnergyAxisConfig()
-    energy_true: EnergyAxisConfig = EnergyAxisConfig()
+    energy: EnergyAxisConfig = EnergyAxisConfig(min="1 TeV", max="10 TeV", nbins=5)
+    energy_true: EnergyAxisConfig = EnergyAxisConfig(
+        min="0.5 TeV", max="20 TeV", nbins=16
+    )
 
 
 class SelectionConfig(GammapyBaseConfig):
     offset_max: AngleType = "2.5 deg"
 
 
-class FovConfig(GammapyBaseConfig):
+class WidthConfig(GammapyBaseConfig):
     width: AngleType = "5 deg"
     height: AngleType = "5 deg"
 
@@ -166,7 +191,7 @@ class FovConfig(GammapyBaseConfig):
 class WcsConfig(GammapyBaseConfig):
     skydir: SkyCoordConfig = SkyCoordConfig()
     binsize: AngleType = "0.02 deg"
-    fov: FovConfig = FovConfig()
+    width: WidthConfig = WidthConfig()
     binsize_irf: AngleType = "0.2 deg"
 
 
@@ -190,9 +215,10 @@ class DatasetsConfig(GammapyBaseConfig):
 class ObservationsConfig(GammapyBaseConfig):
     datastore: Path = Path("$GAMMAPY_DATA/hess-dl3-dr1/")
     obs_ids: List[int] = []
-    obs_file: FilePath = None
+    obs_file: Path = None
     obs_cone: SpatialCircleConfig = SpatialCircleConfig()
     obs_time: TimeRangeConfig = TimeRangeConfig()
+    required_irf: List[RequiredHDUEnum] = ["aeff", "edisp", "psf", "bkg"]
 
 
 class LogConfig(GammapyBaseConfig):
@@ -206,6 +232,9 @@ class LogConfig(GammapyBaseConfig):
 class GeneralConfig(GammapyBaseConfig):
     log: LogConfig = LogConfig()
     outdir: str = "."
+    n_jobs: int = 1
+    datasets_file: Path = None
+    models_file: Path = None
 
 
 class AnalysisConfig(GammapyBaseConfig):
@@ -216,6 +245,8 @@ class AnalysisConfig(GammapyBaseConfig):
     datasets: DatasetsConfig = DatasetsConfig()
     fit: FitConfig = FitConfig()
     flux_points: FluxPointsConfig = FluxPointsConfig()
+    excess_map: ExcessMapConfig = ExcessMapConfig()
+    light_curve: LightCurveConfig = LightCurveConfig()
 
     def __str__(self):
         """Display settings in pretty YAML format."""
