@@ -60,7 +60,8 @@ class Paczynski1990(Fittable1DModel):
 
 
 class CaseBattacharya1998(Fittable1DModel):
-    r"""Radial distribution of the surface density of supernova remnants in the galaxy - Case & Battacharya 1998.
+    r"""Radial distribution of the surface density of supernova remnants in the galaxy
+    - Case & Battacharya 1998.
 
     .. math::
         f(r) = A \left( \frac{r}{r_{\odot}} \right) ^ \alpha \exp
@@ -188,7 +189,8 @@ class YusifovKucuk2004B(Fittable1DModel):
 
 
 class FaucherKaspi2006(Fittable1DModel):
-    r"""Radial distribution of the birth surface density of pulsars in the galaxy - Faucher-Giguere & Kaspi 2006.
+    r"""Radial distribution of the birth surface density of pulsars in the galaxy
+     - Faucher-Giguere & Kaspi 2006.
 
     .. math::
         f(r) = A \frac{1}{\sqrt{2 \pi} \sigma} \exp
