@@ -33,6 +33,10 @@ class TestSourceCatalogHGPS:
         assert cat.tag == "hgps"
         assert len(cat.table) == 78
 
+    @staticmethod
+    def test_str(cat):
+        assert "name: hgps" in str(cat.__str__())
+
     @staticmethod
     def test_positions(cat):
         assert len(cat.positions) == 78
@@ -69,6 +73,9 @@ class TestSourceCatalogHGPS:
         models = cat.to_models(components_status="merged")
         assert len(models) == 78
 
+        gaussians = models.select(tag="gauss", model_type="spatial")
+        assert np.all([m.spatial_model.sigma.value > 0.0 for m in gaussians])
+
 
 @requires_data()
 class TestSourceCatalogObjectHGPS:
