@@ -14,12 +14,19 @@ from .observations import Observation, ObservationChecker, Observations
 
 __all__ = ["DataStore"]
 
+ALL_IRFS = ["aeff", "edisp", "psf", "bkg", "rad_max"]
+ALL_HDUS = ["events", "gti"] + ALL_IRFS
 REQUIRED_IRFS = {
-    "full-enclosure": ["aeff", "edisp", "psf", "bkg"],
-    "point-like": ["aeff", "edisp"],
-    "all-optional": ["aeff", "edisp", "psf", "bkg", "rad_max"],
+    "full-enclosure": {"aeff", "edisp", "psf", "bkg"},
+    "point-like": {"aeff", "edisp"},
+    "all-optional": {},
 }
 
+
+class MissingRequiredHDU(IOError):
+    pass
+
+
 log = logging.getLogger(__name__)
 log.setLevel(logging.INFO)
 
@@ -30,8 +37,6 @@ class DataStore:
     The data selection and access happens using an observation
     and an HDU index file as described at :ref:`gadf:iact-storage`.
 
-    For a usage example see `cta.html <../tutorials/data/cta.html>`__
-
     Parameters
     ----------
     hdu_table : `~gammapy.data.HDUIndexTable`
@@ -59,6 +64,8 @@ class DataStore:
     Observatory name: 'N/A'
     Number of observations: 105
     <BLANKLINE>
+
+    For further usage example see :doc:`/tutorials/data/cta` tutorial.
     """
 
     DEFAULT_HDU_TABLE = "hdu-index.fits.gz"
@@ -193,9 +200,10 @@ class DataStore:
         events_paths : list of str or Path
             List of paths to the events files
         irfs_paths : str, Path, or list of str or Path
-            Path to the IRFs file. If a list is provided it must be the same length than `events_paths`.
-            If None the events files have to contain CALDB and IRF header keywords to locate the IRF files,
-            otherwise the IRFs are assumed to be contained in the events files.
+            Path to the IRFs file. If a list is provided it must be the same length
+            than `events_paths`. If None the events files have to contain CALDB and
+            IRF header keywords to locate the IRF files, otherwise the IRFs are
+            assumed to be contained in the events files.
 
         Returns
         -------
@@ -284,15 +292,34 @@ class DataStore:
 
         kwargs = {"obs_id": int(obs_id)}
 
-        if required_irf == "full-enclosure":
-            hdus = ["events", "gti", "aeff", "edisp", "psf", "bkg"]
-        elif required_irf == "point-like":
-            hdus = ["events", "gti", "aeff", "edisp"]
-        else:
-            hdus = ["events", "gti"] + required_irf
+        # check for the "short forms"
+        if isinstance(required_irf, str):
+            required_irf = REQUIRED_IRFS[required_irf]
 
-        for hdu in hdus:
-            kwargs[hdu] = self.hdu_table.hdu_location(obs_id=obs_id, hdu_type=hdu)
+        if not set(required_irf).issubset(ALL_IRFS):
+            difference = set(required_irf).difference(ALL_IRFS)
+            raise ValueError(
+                f"{difference} is not a valid hdu key. Choose from: {ALL_IRFS}"
+            )
+
+        required_hdus = {"event", "gti"}.union(required_irf)
+
+        missing_hdus = []
+        for hdu in ALL_HDUS:
+            hdu_location = self.hdu_table.hdu_location(
+                obs_id=obs_id,
+                hdu_type=hdu,
+                warn_missing=False,
+            )
+            if hdu_location is not None:
+                kwargs[hdu] = hdu_location
+            elif hdu in required_hdus:
+                missing_hdus.append(hdu)
+
+        if len(missing_hdus) > 0:
+            raise MissingRequiredHDU(
+                f"Required HDUs {missing_hdus} not found in observation {obs_id}"
+            )
 
         return Observation(**kwargs)
 
@@ -335,18 +362,6 @@ class DataStore:
             Container holding a list of `~gammapy.data.Observation`
         """
 
-        all_hdu = REQUIRED_IRFS["all-optional"]
-        is_all_optional = required_irf == "all-optional"
-
-        if isinstance(required_irf, str) and required_irf in REQUIRED_IRFS.keys():
-            required_irf = REQUIRED_IRFS[required_irf]
-
-        if not set(required_irf).issubset(all_hdu):
-            difference = set(required_irf).difference(all_hdu)
-            raise ValueError(
-                f"{difference} is not a valid hdu key. Choose from: {all_hdu}"
-            )
-
         if obs_id is None:
             obs_id = self.obs_ids
 
@@ -361,11 +376,12 @@ class DataStore:
                     continue
                 else:
                     raise err
+            except MissingRequiredHDU as e:
+                log.warning(f"Skipping run with missing HDUs; {e}")
+                continue
+
+            obs_list.append(obs)
 
-            if is_all_optional or set(required_irf).issubset(obs.available_hdus):
-                obs_list.append(obs)
-            else:
-                log.warning(f"Skipping run with missing HDUs; obs_id: {_!r}")
         log.info(f"Observations selected: {len(obs_list)} out of {len(obs_id)}.")
         return Observations(obs_list)
 
