@@ -7,7 +7,7 @@ from astropy.table import Table
 from regions import CircleSkyRegion
 import matplotlib.pyplot as plt
 from gammapy.data import GTI
-from gammapy.irf import EDispKernelMap, EDispMap, PSFKernel, PSFMap
+from gammapy.irf import EDispKernelMap, EDispMap, PSFKernel, PSFMap, RecoPSFMap
 from gammapy.maps import Map, MapAxis
 from gammapy.modeling.models import DatasetModels, FoVBackgroundModel
 from gammapy.stats import (
@@ -118,7 +118,7 @@ class MapDataset(Dataset):
         Mask to apply to the likelihood for fitting.
     psf : `~gammapy.irf.PSFMap` or `~gammapy.utils.fits.HDULocation`
         PSF kernel
-    edisp : `~gammapy.irf.EDispKernel` or `~gammapy.irf.EDispMap` or `~gammapy.utils.fits.HDULocation`
+    edisp : `~gammapy.irf.EDispMap` or `~gammapy.utils.fits.HDULocation`
         Energy dispersion kernel
     mask_safe : `~gammapy.maps.WcsNDMap` or `~gammapy.utils.fits.HDULocation`
         Mask defining the safe data range.
@@ -136,12 +136,13 @@ class MapDataset(Dataset):
     Examples
     --------
     >>> from gammapy.datasets import MapDataset
-    >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz", name="cta_dataset")
+    >>> filename = "$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz"
+    >>> dataset = MapDataset.read(filename, name="cta-dataset")
     >>> print(dataset)
     MapDataset
     ----------
     <BLANKLINE>
-      Name                            : cta_dataset
+      Name                            : cta-dataset
     <BLANKLINE>
       Total counts                    : 104317
       Total background counts         : 91507.70
@@ -224,7 +225,8 @@ class MapDataset(Dataset):
 
         if edisp and not isinstance(edisp, (EDispMap, EDispKernelMap, HDULocation)):
             raise ValueError(
-                f"'edisp' must be a 'EDispMap', `EDispKernelMap` or 'HDULocation' object, got {type(edisp)}"
+                "'edisp' must be a 'EDispMap', `EDispKernelMap` or 'HDULocation' "
+                f"object, got `{type(edisp)}` instead."
             )
 
         self.edisp = edisp
@@ -402,7 +404,7 @@ class MapDataset(Dataset):
 
     @property
     def energy_range(self):
-        """Energy range maps defined by the full mask (mask_safe and mask_fit)."""
+        """Energy range maps defined by the mask_safe and mask_fit."""
         return self._energy_range(self.mask)
 
     @property
@@ -417,7 +419,7 @@ class MapDataset(Dataset):
 
     @property
     def energy_range_total(self):
-        """Largest energy range among all pixels, defined by the full mask (mask_safe and mask_fit)."""
+        """Largest energy range among all pixels, defined by mask_safe and mask_fit."""
         energy_min_map, energy_max_map = self.energy_range
         return np.nanmin(energy_min_map.quantity), np.nanmax(energy_max_map.quantity)
 
@@ -562,7 +564,10 @@ class MapDataset(Dataset):
                 kwargs["edisp"] = EDispMap.from_geom(geom_edisp)
 
         if geom_psf:
-            kwargs["psf"] = PSFMap.from_geom(geom_psf)
+            if "energy_true" in geom_psf.axes.names:
+                kwargs["psf"] = PSFMap.from_geom(geom_psf)
+            elif "energy" in geom_psf.axes.names:
+                kwargs["psf"] = RecoPSFMap.from_geom(geom_psf)
 
         kwargs.setdefault(
             "gti", GTI.create([] * u.s, [] * u.s, reference_time=reference_time)
@@ -617,9 +622,16 @@ class MapDataset(Dataset):
         >>> from gammapy.maps import WcsGeom, MapAxis
 
         >>> energy_axis = MapAxis.from_energy_bounds(1.0, 10.0, 4, unit="TeV")
-        >>> energy_axis_true = MapAxis.from_energy_bounds( 0.5, 20, 10, unit="TeV", name="energy_true")
-        >>> geom = WcsGeom.create(skydir=(83.633, 22.014), binsz=0.02, width=(2, 2), frame="icrs", proj="CAR", axes=[energy_axis])
-
+        >>> energy_axis_true = MapAxis.from_energy_bounds(
+                    0.5, 20, 10, unit="TeV", name="energy_true"
+                )
+        >>> geom = WcsGeom.create(
+                    skydir=(83.633, 22.014),
+                    binsz=0.02, width=(2, 2),
+                    frame="icrs",
+                    proj="CAR",
+                    axes=[energy_axis]
+                )
         >>> empty = MapDataset.create(geom=geom, energy_axis_true=energy_axis_true, name="empty")
         """
 
@@ -632,7 +644,9 @@ class MapDataset(Dataset):
         )
 
         kwargs.update(geoms)
-        return cls.from_geoms(reference_time=reference_time, name=name, **kwargs)
+        return cls.from_geoms(
+            reference_time=reference_time, name=name, meta_table=meta_table, **kwargs
+        )
 
     @property
     def mask_safe_image(self):
@@ -786,6 +800,11 @@ class MapDataset(Dataset):
         if self.mask_safe and other.mask_safe:
             self.mask_safe.stack(other.mask_safe)
 
+        if self.mask_fit and other.mask_fit:
+            self.mask_fit.stack(other.mask_fit)
+        elif other.mask_fit:
+            self.mask_fit = other.mask_fit.copy()
+
         if self.gti and other.gti:
             self.gti.stack(other.gti)
             self.gti = self.gti.union()
@@ -937,7 +956,7 @@ class MapDataset(Dataset):
         --------
         >>> from gammapy.datasets import MapDataset
         >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
-        >>> kwargs = {"markerfacecolor": "blue", "markersize":8, "marker":'s', } #plot big blue squares
+        >>> kwargs = {"markerfacecolor": "blue", "markersize":8, "marker":'s'}
         >>> dataset.plot_residuals_spectral(method="diff/sqrt(model)", **kwargs) # doctest: +SKIP
 
         """
@@ -1032,10 +1051,10 @@ class MapDataset(Dataset):
         >>> import astropy.units as u
         >>> from gammapy.datasets import MapDataset
         >>> dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
-        >>> reg = CircleSkyRegion(SkyCoord(0,0, unit="deg", frame="galactic"), radius=1.0*u.deg)
+        >>> reg = CircleSkyRegion(SkyCoord(0,0, unit="deg", frame="galactic"), radius=1.0 * u.deg)
         >>> kwargs_spatial = {"cmap": "RdBu_r", "vmin":-5, "vmax":5, "add_cbar": True}
-        >>> kwargs_spectral = {"region":reg, "markerfacecolor": "blue", "markersize":8, "marker":'s'}
-        >>> dataset.plot_residuals(kwargs_spatial=kwargs_spatial, kwargs_spectral=kwargs_spectral) # doctest: +SKIP
+        >>> kwargs_spectral = {"region":reg, "markerfacecolor": "blue", "markersize": 8, "marker": "s"}  # noqa: E501
+        >>> dataset.plot_residuals(kwargs_spatial=kwargs_spatial, kwargs_spectral=kwargs_spectral) # doctest: +SKIP noqa: E501
         """
         ax_spatial, ax_spectral = get_axes(
             ax_spatial,
@@ -1098,6 +1117,10 @@ class MapDataset(Dataset):
         exclude_primary = slice(1, None)
 
         hdu_primary = fits.PrimaryHDU()
+
+        header = hdu_primary.header
+        header["NAME"] = self.name
+
         hdulist = fits.HDUList([hdu_primary])
         if self.counts is not None:
             hdulist += self.counts.to_hdulist(hdu="counts")[exclude_primary]
@@ -1225,6 +1248,7 @@ class MapDataset(Dataset):
 
     @classmethod
     def _read_lazy(cls, name, filename, cache, format=format):
+        name = make_name(name)
         kwargs = {"name": name}
         try:
             kwargs["gti"] = GTI.read(filename)
@@ -1284,15 +1308,19 @@ class MapDataset(Dataset):
         dataset : `MapDataset`
             Map dataset.
         """
-        name = make_name(name)
+
+        if name is None:
+            header = fits.getheader(str(make_path(filename)))
+            name = header.get("NAME", name)
+        ds_name = make_name(name)
 
         if lazy:
             return cls._read_lazy(
-                name=name, filename=filename, cache=cache, format=format
+                name=ds_name, filename=filename, cache=cache, format=format
             )
         else:
             with fits.open(str(make_path(filename)), memmap=False) as hdulist:
-                return cls.from_hdulist(hdulist, name=name, format=format)
+                return cls.from_hdulist(hdulist, name=ds_name, format=format)
 
     @classmethod
     def from_dict(cls, data, lazy=False, cache=True):
@@ -1329,11 +1357,12 @@ class MapDataset(Dataset):
 
         counts = 0
         background, excess, sqrt_ts = np.nan, np.nan, np.nan
+
         if self.counts:
-            summed_stat = self._counts_statistic[mask].sum()
-            counts = summed_stat.n_on
+            counts = self.counts.data[mask].sum()
 
             if self.background:
+                summed_stat = self._counts_statistic[mask].sum()
                 background = summed_stat.n_bkg
                 excess = summed_stat.n_sig
                 sqrt_ts = summed_stat.sqrt_ts
@@ -2053,7 +2082,7 @@ class MapDatasetOnOff(MapDataset):
         return alpha
 
     def npred_background(self):
-        """Predicted background counts (mu_bkg) estimated from the marginalized likelihood estimate.
+        """Predicted background counts estimated from the marginalized likelihood estimate.
 
         See :ref:`wstat`
 
@@ -2125,7 +2154,7 @@ class MapDatasetOnOff(MapDataset):
         name=None,
         **kwargs,
     ):
-        """Create a MapDatasetOnOff object  switch zero filled maps according to the specified geometries
+        """Create an empty `MapDatasetOnOff` object according to the specified geometries
 
         Parameters
         ----------
@@ -2221,6 +2250,7 @@ class MapDatasetOnOff(MapDataset):
 
     def to_map_dataset(self, name=None):
         """Convert a MapDatasetOnOff to  MapDataset
+
         The background model template is taken as alpha * counts_off
 
         Parameters
@@ -2313,8 +2343,8 @@ class MapDatasetOnOff(MapDataset):
             acceptance_off = total_off / total_alpha
             average_alpha = total_alpha.data.sum() / total_off.data.sum()
 
-        # For the bins where the stacked OFF counts equal 0, the alpha value is performed by weighting on the total
-        # OFF counts of each run
+        # For the bins where the stacked OFF counts equal 0, the alpha value is
+        # performed by weighting on the total OFF counts of each run
         is_zero = total_off.data == 0
         acceptance_off.data[is_zero] = 1 / average_alpha
 
@@ -2336,6 +2366,8 @@ class MapDatasetOnOff(MapDataset):
 
         Parameters
         ----------
+        npred_background : `~gammapy.maps.Map`
+                Expected number of background counts in the on region
         random_state : {int, 'random-seed', 'global-rng', `~numpy.random.RandomState`}
                 Defines random number generator initialisation.
                 Passed to `~gammapy.utils.random.get_random_state`.
