@@ -216,6 +216,14 @@ def get_map_dataset(geom, geom_etrue, edisp="edispmap", name="test", **kwargs):
     )
 
 
+def test_map_dataset_name():
+    with pytest.raises(ValueError, match="of type '<class 'int'>"):
+        _ = MapDataset(name=6353)
+
+    with pytest.raises(ValueError, match="of type '<class 'list'>"):
+        _ = MapDataset(name=[1233, "234"])
+
+
 @requires_data()
 def test_map_dataset_str(sky_model, geom, geom_etrue):
     dataset = get_map_dataset(geom, geom_etrue)
@@ -582,6 +590,8 @@ def test_map_dataset_fits_io(tmp_path, sky_model, geom, geom_etrue):
 
     dataset_new = MapDataset.read(tmp_path / "test.fits")
 
+    assert dataset_new.name == "test"
+
     assert dataset_new.mask.data.dtype == bool
 
     assert_allclose(dataset.counts.data, dataset_new.counts.data)
@@ -869,6 +879,7 @@ def test_stack(sky_model):
         background=bkg1,
         exposure=exp1,
         mask_safe=mask1,
+        mask_fit=mask1,
         name="dataset-1",
         edisp=edisp,
         meta_table=Table({"OBS_ID": [0]}),
@@ -893,6 +904,7 @@ def test_stack(sky_model):
         background=bkg2,
         exposure=exp2,
         mask_safe=mask2,
+        mask_fit=mask2,
         name="dataset-2",
         edisp=edisp,
         meta_table=Table({"OBS_ID": [1]}),
@@ -915,6 +927,7 @@ def test_stack(sky_model):
     assert_allclose(stacked.npred_background().data.sum(), 1360.00, 1e-5)
     assert_allclose(stacked.counts.data.sum(), 9000, 1e-5)
     assert_allclose(stacked.mask_safe.data.sum(), 4600)
+    assert_allclose(stacked.mask_fit.data.sum(), 4600)
     assert_allclose(stacked.exposure.data.sum(), 1.6e11)
 
     assert_allclose(stacked.meta_table["OBS_ID"][0], [0, 1])
@@ -1096,6 +1109,7 @@ def get_map_dataset_onoff(images, **kwargs):
         psf=psf,
         edisp=edisp,
         gti=gti,
+        name="MapDatasetOnOff-test",
         **kwargs,
     )
 
@@ -1146,6 +1160,7 @@ def test_map_dataset_on_off_fits_io(images, lazy, tmp_path):
             dataset_new = MapDatasetOnOff.read(tmp_path / "test.fits", lazy=lazy)
     else:
         dataset_new = MapDatasetOnOff.read(tmp_path / "test.fits", lazy=lazy)
+        assert dataset_new.name == "MapDatasetOnOff-test"
         assert dataset_new.mask.data.dtype == bool
         assert dataset_new.meta_table["livetime"] == 1.0 * u.h
         assert dataset_new.meta_table["obs_id"] == 111
@@ -1678,13 +1693,14 @@ def test_region_geom_io(tmpdir):
     axis = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=1)
     geom = RegionGeom.create("icrs;circle(0, 0, 0.2)", axes=[axis])
 
-    dataset = MapDataset.create(geom)
+    dataset = MapDataset.create(geom, name="geom-test")
 
     filename = tmpdir / "test.fits"
     dataset.write(filename)
 
     dataset = MapDataset.read(filename, format="gadf")
 
+    assert dataset.name == "geom-test"
     assert isinstance(dataset.counts.geom, RegionGeom)
     assert isinstance(dataset.edisp.edisp_map.geom, RegionGeom)
     assert isinstance(dataset.psf.psf_map.geom, RegionGeom)
@@ -1725,6 +1741,18 @@ def test_dataset_mixed_geom(tmpdir):
     assert isinstance(dataset.psf.psf_map.geom.region, CircleSkyRegion)
     assert isinstance(dataset.edisp.edisp_map.geom.region, CircleSkyRegion)
 
+    geom_psf_reco = RegionGeom.create(
+        "icrs;circle(0, 0, 0.2)", axes=[rad_axis, energy_axis]
+    )
+
+    dataset = MapDataset.from_geoms(
+        geom=geom,
+        geom_exposure=geom_exposure,
+        geom_psf=geom_psf_reco,
+        geom_edisp=geom_edisp,
+    )
+    assert dataset.psf.tag == "psf_map_reco"
+
 
 @requires_data()
 def test_map_dataset_region_geom_npred():
