@@ -1,3 +1,6 @@
+import numpy as np
+
+
 def get_figure(fig, width, height):
     import matplotlib.pyplot as plt
 
@@ -23,3 +26,11 @@ def get_axes(ax1, ax2, width, height, args1, args2, kwargs1=None, kwargs2=None):
         raise ValueError("Either both or no Axes must be provided")
 
     return ax1, ax2
+
+
+def get_nearest_valid_exposure_position(exposure, position=None):
+    mask_exposure = exposure > 0.0 * exposure.unit
+    mask_exposure = mask_exposure.reduce_over_axes(func=np.logical_or)
+    if not position:
+        position = mask_exposure.geom.center_skydir
+    return mask_exposure.mask_nearest_position(position)
