@@ -6,7 +6,7 @@ from astropy.io import fits
 from astropy.table import Table
 from astropy.utils import classproperty
 from gammapy.data import GTI
-from gammapy.maps import Map, Maps
+from gammapy.maps import Map, Maps, TimeMapAxis
 from gammapy.modeling.models import (
     Models,
     PowerLawSpectralModel,
@@ -131,8 +131,8 @@ class FluxMaps:
         * sqrt_ts : optional, the square root of the TS, when relevant.
         * success : optional, a boolean tagging the validity of the estimation
     reference_model : `~gammapy.modeling.models.SkyModel`, optional
-        the reference model to use for conversions.
-        If None, a model consisting of a point source with a power law spectrum of index 2 is assumed.
+        The reference model to use for conversions. If None, a model consisting
+        of a point source with a power law spectrum of index 2 is assumed.
     meta : dict, optional
         Dict of metadata.
     gti : `~gammapy.data.GTI`, optional
@@ -156,6 +156,7 @@ class FluxMaps:
         if meta is None:
             meta = {}
 
+        meta.setdefault("sed_type_init", "likelihood")
         self.meta = meta
         self.gti = gti
         self._filter_success_nan = filter_success_nan
@@ -232,9 +233,17 @@ class FluxMaps:
             if required.issubset(quantities):
                 return sed_type
 
+    @property
+    def is_convertible_to_flux_sed_type(self):
+        """Check whether differential sed type is convertible to integral sed type"""
+        if self.sed_type_init in ["dnde", "e2dnde"]:
+            return self.energy_axis.node_type == "edges"
+
+        return True
+
     @property
     def has_ul(self):
-        """Whether the flux estimate has either sqrt(ts) or ts defined"""
+        """Whether the flux estimate has norm_ul defined"""
         return "norm_ul" in self._data
 
     @property
@@ -254,7 +263,7 @@ class FluxMaps:
 
     @property
     def n_sigma(self):
-        """n sigma UL"""
+        """n sigma"""
         return self.meta.get("n_sigma", 1)
 
     @property
@@ -288,6 +297,14 @@ class FluxMaps:
         """Initial sed type"""
         return self.meta.get("sed_type_init")
 
+    @property
+    def sed_type_plot_default(self):
+        """Initial sed type"""
+        if self.sed_type_init == "likelihood":
+            return "dnde"
+
+        return self.sed_type_init
+
     @property
     def geom(self):
         """Reference map geometry (`Geom`)"""
@@ -427,6 +444,13 @@ class FluxMaps:
             data = np.expand_dims(data, axis=idx)
         return data
 
+    @staticmethod
+    def _use_center_as_labels(input_map):
+        """Change the node_type of the input map."""
+        energy_axis = input_map.geom.axes["energy"]
+        energy_axis.use_center_as_plot_labels = True
+        return input_map
+
     @property
     def npred_excess_ref(self):
         """Predicted excess reference counts"""
@@ -547,12 +571,17 @@ class FluxMaps:
     def e2dnde_ref(self):
         """Reference differential flux * energy ** 2"""
         energy = self.energy_axis.center
-        result = self.reference_spectral_model(energy) * energy ** 2
+        result = self.reference_spectral_model(energy) * energy**2
         return result[self._expand_slice]
 
     @property
     def flux_ref(self):
         """Reference integral flux"""
+        if not self.is_convertible_to_flux_sed_type:
+            raise ValueError(
+                "Missing energy range definition, cannot convert to sed type 'flux'."
+            )
+
         energy_min = self.energy_axis.edges[:-1]
         energy_max = self.energy_axis.edges[1:]
         result = self.reference_spectral_model.integral(energy_min, energy_max)
@@ -561,6 +590,11 @@ class FluxMaps:
     @property
     def eflux_ref(self):
         """Reference energy flux"""
+        if not self.is_convertible_to_flux_sed_type:
+            raise ValueError(
+                "Missing energy range definition, cannot convert to sed type 'eflux'."
+            )
+
         energy_min = self.energy_axis.edges[:-1]
         energy_max = self.energy_axis.edges[1:]
         result = self.reference_spectral_model.energy_flux(energy_min, energy_max)
@@ -569,52 +603,52 @@ class FluxMaps:
     @property
     def dnde(self):
         """Return differential flux (dnde) SED values."""
-        return self.norm * self.dnde_ref
+        return self._use_center_as_labels(self.norm * self.dnde_ref)
 
     @property
     def dnde_err(self):
         """Return differential flux (dnde) SED errors."""
-        return self.norm_err * self.dnde_ref
+        return self._use_center_as_labels(self.norm_err * self.dnde_ref)
 
     @property
     def dnde_errn(self):
         """Return differential flux (dnde) SED negative errors."""
-        return self.norm_errn * self.dnde_ref
+        return self._use_center_as_labels(self.norm_errn * self.dnde_ref)
 
     @property
     def dnde_errp(self):
         """Return differential flux (dnde) SED positive errors."""
-        return self.norm_errp * self.dnde_ref
+        return self._use_center_as_labels(self.norm_errp * self.dnde_ref)
 
     @property
     def dnde_ul(self):
         """Return differential flux (dnde) SED upper limit."""
-        return self.norm_ul * self.dnde_ref
+        return self._use_center_as_labels(self.norm_ul * self.dnde_ref)
 
     @property
     def e2dnde(self):
         """Return differential energy flux (e2dnde) SED values."""
-        return self.norm * self.e2dnde_ref
+        return self._use_center_as_labels(self.norm * self.e2dnde_ref)
 
     @property
     def e2dnde_err(self):
         """Return differential energy flux (e2dnde) SED errors."""
-        return self.norm_err * self.e2dnde_ref
+        return self._use_center_as_labels(self.norm_err * self.e2dnde_ref)
 
     @property
     def e2dnde_errn(self):
         """Return differential energy flux (e2dnde) SED negative errors."""
-        return self.norm_errn * self.e2dnde_ref
+        return self._use_center_as_labels(self.norm_errn * self.e2dnde_ref)
 
     @property
     def e2dnde_errp(self):
         """Return differential energy flux (e2dnde) SED positive errors."""
-        return self.norm_errp * self.e2dnde_ref
+        return self._use_center_as_labels(self.norm_errp * self.e2dnde_ref)
 
     @property
     def e2dnde_ul(self):
         """Return differential energy flux (e2dnde) SED upper limit."""
-        return self.norm_ul * self.e2dnde_ref
+        return self._use_center_as_labels(self.norm_ul * self.e2dnde_ref)
 
     @property
     def flux(self):
@@ -720,7 +754,7 @@ class FluxMaps:
             gti=self.gti,
         )
 
-    def to_maps(self, sed_type="likelihood"):
+    def to_maps(self, sed_type=None):
         """Return maps in a given SED type.
 
         Parameters
@@ -735,6 +769,9 @@ class FluxMaps:
         """
         maps = Maps()
 
+        if sed_type is None:
+            sed_type = self.sed_type_init
+
         for quantity in self.all_quantities(sed_type=sed_type):
             m = getattr(self, quantity, None)
             if m is not None:
@@ -783,6 +820,45 @@ class FluxMaps:
             data=data, reference_model=reference.reference_model, meta=meta, gti=gti
         )
 
+    def iter_by_axis(self, axis_name, keepdims=False):
+        """Create a set of FluxMaps by splitting along an axis.
+
+        Parameters
+        ----------
+        axis_name : str
+             Name of the axis to split on
+        keepdims : bool
+            Whether to keep the split axis with a single bin
+
+        Returns
+        -------
+        flux_maps : `FluxMap`
+            FluxMap iteration
+
+        """
+
+        split_maps = {}
+        axis = self.geom.axes[axis_name]
+        gti = self.gti
+
+        for amap in self.available_quantities:
+            split_maps[amap] = list(getattr(self, amap).iter_by_axis(axis_name))
+
+        for idx in range(axis.nbin):
+            maps = {}
+            for amap in self.available_quantities:
+                maps[amap] = split_maps[amap][idx]
+                if isinstance(axis, TimeMapAxis):
+                    gti = self.gti.select_time([axis.time_min[idx], axis.time_max[idx]])
+
+            yield self.__class__.from_maps(
+                maps=maps,
+                sed_type=self.sed_type_init,
+                reference_model=self.reference_model,
+                gti=gti,
+                meta=self.meta,
+            )
+
     @classmethod
     def from_maps(cls, maps, sed_type=None, reference_model=None, gti=None, meta=None):
         """Create FluxMaps from a dictionary of maps.
@@ -852,7 +928,7 @@ class FluxMaps:
 
         return cls(data=data, reference_model=reference_model, gti=gti, meta=meta)
 
-    def to_hdulist(self, sed_type="likelihood", hdu_bands=None):
+    def to_hdulist(self, sed_type=None, hdu_bands=None):
         """Convert flux map to list of HDUs.
 
         For now, one cannot export the reference model.
@@ -870,6 +946,9 @@ class FluxMaps:
         hdulist : `~astropy.io.fits.HDUList`
             Map dataset list of HDUs.
         """
+        if sed_type is None:
+            sed_type = self.sed_type_init
+
         exclude_primary = slice(1, None)
 
         hdu_primary = fits.PrimaryHDU()
@@ -925,9 +1004,7 @@ class FluxMaps:
             maps=maps, sed_type=sed_type, reference_model=reference_model, gti=gti
         )
 
-    def write(
-        self, filename, filename_model=None, overwrite=False, sed_type="likelihood"
-    ):
+    def write(self, filename, filename_model=None, overwrite=False, sed_type=None):
         """Write flux map to file.
 
         Parameters
@@ -942,6 +1019,9 @@ class FluxMaps:
         sed_type : str
             sed type to convert to. Default is `likelihood`
         """
+        if sed_type is None:
+            sed_type = self.sed_type_init
+
         filename = make_path(filename)
 
         if filename_model is None:
