@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Functions to compute TS images."""
-import contextlib
 import functools
 import logging
 import warnings
@@ -10,6 +9,7 @@ import scipy.optimize
 from astropy.coordinates import Angle
 from astropy.utils import lazyproperty
 from gammapy.datasets.map import MapEvaluator
+from gammapy.datasets.utils import get_nearest_valid_exposure_position
 from gammapy.maps import Map, Maps
 from gammapy.modeling.models import PointSpatialModel, PowerLawSpectralModel, SkyModel
 from gammapy.stats import cash_sum_cython, f_cash_root_cython, norm_bounds_cython
@@ -54,7 +54,7 @@ class TSMapEstimator(Estimator):
     r"""Compute TS map from a MapDataset using different optimization methods.
 
     The map is computed fitting by a single parameter norm fit. The fit is
-    simplified by finding roots of the the derivative of the fit statistics using
+    simplified by finding roots of the derivative of the fit statistics using
     various root finding algorithms. The approach is described in Appendix A
     in Stewart (2009).
 
@@ -111,6 +111,35 @@ class TSMapEstimator(Estimator):
 
     Where :math:`F` is the fitted flux norm.
 
+    Examples
+    --------
+    >>> import astropy.units as u
+    >>> from gammapy.estimators import TSMapEstimator
+    >>> from gammapy.datasets import MapDataset
+    >>> from gammapy.modeling.models import (SkyModel, PowerLawSpectralModel,PointSpatialModel)
+    >>> spatial_model = PointSpatialModel()
+    >>> spectral_model = PowerLawSpectralModel(amplitude="1e-22 cm-2 s-1 keV-1", index=2)
+    >>> model = SkyModel(spatial_model=spatial_model, spectral_model=spectral_model)
+    >>> dataset = MapDataset.read("$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc.fits.gz")
+    >>> estimator = TSMapEstimator(
+                model, kernel_width="1 deg",energy_edges=[10, 100] * u.GeV, downsampling_factor=4
+            )
+    >>> maps = estimator.run(dataset)
+    >>> print(maps)
+    FluxMaps
+    --------
+    <BLANKLINE>
+      geom                   : WcsGeom
+      axes                   : ['lon', 'lat', 'energy']
+      shape                  : (400, 200, 1)
+      quantities             : ['ts', 'norm', 'niter', 'norm_err', 'npred', 'npred_excess', 'stat', 'stat_null', 'success']  # noqa: E501
+      ref. model             : pl
+      n_sigma                : 1
+      n_sigma_ul             : 2
+      sqrt_ts_threshold_ul   : 2
+      sed type init          : likelihood
+
+
     References
     ----------
     [Stewart2009]_
@@ -189,7 +218,8 @@ class TSMapEstimator(Estimator):
     def estimate_kernel(self, dataset):
         """Get the convolution kernel for the input dataset.
 
-        Convolves the model with the PSFKernel at the center of the dataset.
+        Convolves the model with the IRFs at the center of the dataset,
+        or at the nearest position with non-zero exposure.
 
         Parameters
         ----------
@@ -210,10 +240,17 @@ class TSMapEstimator(Estimator):
         model = self.model.copy()
         model.spatial_model.position = geom.center_skydir
 
-        # Creating exposure map with exposure at map center
-        exposure = Map.from_geom(geom, unit="cm2 s1")
-        exposure_center = dataset.exposure.to_region_nd_map(geom.center_skydir)
-        exposure.data[...] = exposure_center.data
+        # Creating exposure map with the mean non-null exposure
+        exposure = Map.from_geom(geom, unit=dataset.exposure.unit)
+        position = get_nearest_valid_exposure_position(
+            dataset.exposure, geom.center_skydir
+        )
+        exposure_position = dataset.exposure.to_region_nd_map(position)
+        if not np.any(exposure_position.data):
+            raise ValueError(
+                "No valid exposure. Impossible to compute kernel for TS Map."
+            )
+        exposure.data[...] = exposure_position.data
 
         # We use global evaluation mode to not modify the geometry
         evaluator = MapEvaluator(model=model)
@@ -252,7 +289,7 @@ class TSMapEstimator(Estimator):
         if kernel is None:
             kernel = self.estimate_kernel(dataset=dataset)
 
-        kernel = kernel.data / np.sum(kernel.data ** 2)
+        kernel = kernel.data / np.sum(kernel.data**2)
 
         with np.errstate(invalid="ignore", divide="ignore"):
             flux = (dataset.counts - dataset.npred()) / exposure
@@ -390,12 +427,10 @@ class TSMapEstimator(Estimator):
         if self.n_jobs is None:
             results = list(map(wrap, positions))
         else:
-            with contextlib.closing(Pool(processes=self.n_jobs)) as pool:
+            with Pool(processes=self.n_jobs) as pool:
                 log.info("Using {} jobs to compute TS map.".format(self.n_jobs))
                 results = pool.map(wrap, positions)
 
-            pool.join()
-
         result = {}
 
         j, i = zip(*positions)
@@ -524,7 +559,7 @@ class SimpleMapDataset:
 
     def stat_2nd_derivative(self, norm):
         """Stat 2nd derivative"""
-        term_top = self.model ** 2 * self.counts
+        term_top = self.model**2 * self.counts
         term_bottom = (self.background + norm * self.model) ** 2
         mask = term_bottom == 0
         return (term_top / term_bottom)[~mask].sum()
@@ -627,7 +662,7 @@ class BrentqFluxEstimator(Estimator):
         norm_err = result["norm_err"]
 
         def ts_diff(x):
-            return (stat_best + n_sigma ** 2) - dataset.stat_sum(x)
+            return (stat_best + n_sigma**2) - dataset.stat_sum(x)
 
         if positive:
             min_norm = norm
