@@ -96,7 +96,7 @@ class Background3D(BackgroundIRF):
     data : `~np.ndarray`
         Data array.
     unit : str or `~astropy.units.Unit`
-        Data unit usuually ``s^-1 MeV^-1 sr^-1``
+        Data unit usually ``s^-1 MeV^-1 sr^-1``
     meta : dict
         Meta data
 
@@ -174,8 +174,11 @@ class Background3D(BackgroundIRF):
         cols = min(ncols, n)
         rows = 1 + (n - 1) // cols
         width = 12
+        cfraction = 0.0
+        if add_cbar:
+            cfraction = 0.15
         if figsize is None:
-            figsize = (width, width * rows / cols)
+            figsize = (width, rows * width // (cols * (1 + cfraction)))
 
         fig, axes = plt.subplots(
             ncols=cols,
@@ -202,13 +205,15 @@ class Background3D(BackgroundIRF):
             ax.set_title(str(ee))
             if add_cbar:
                 label = f"Background [{bkg.unit}]"
-                ax.figure.colorbar(caxes, ax=ax, label=label)
+                cbar = ax.figure.colorbar(caxes, ax=ax, label=label, fraction=cfraction)
+                cbar.formatter.set_powerlimits((0, 0))
 
             row, col = np.unravel_index(i, shape=(rows, cols))
             if col > 0:
                 ax.set_ylabel("")
             if row < rows - 1:
                 ax.set_xlabel("")
+            ax.set_aspect("equal", "box")
 
 
 class Background2D(BackgroundIRF):
@@ -231,8 +236,6 @@ class Background2D(BackgroundIRF):
     tag = "bkg_2d"
     required_axes = ["energy", "offset"]
     default_unit = u.s**-1 * u.MeV**-1 * u.sr**-1
-    default_interp_kwargs = dict(bounds_error=False, fill_value=0.0)
-    """Default Interpolation kwargs."""
 
     def to_3d(self):
         """ "Convert to Background3D"""
