@@ -76,7 +76,8 @@ class IRF(metaclass=abc.ABCMeta):
             self.data = data.value
             if not self.default_unit.is_equivalent(data.unit):
                 raise ValueError(
-                    f"Error: {data.unit} is not an allowed unit. {self.tag} requires {self.default_unit} data quantities."
+                    f"Error: {data.unit} is not an allowed unit. {self.tag} "
+                    f"requires {self.default_unit} data quantities."
                 )
             else:
                 self._unit = data.unit
@@ -448,7 +449,8 @@ class IRF(metaclass=abc.ABCMeta):
         irf : `IRF`
             IRF class.
         """
-        axes = MapAxes.from_table(table=table, format=format)[cls.required_axes]
+        axes = MapAxes.from_table(table=table, format=format)
+        axes = axes[cls.required_axes]
         column_name = IRF_DL3_HDU_SPECIFICATION[cls.tag]["column_name"]
         data = table[column_name].quantity[0].transpose()
 
@@ -554,6 +556,33 @@ class IRF(metaclass=abc.ABCMeta):
             data=data, axes=axes, meta=self.meta.copy(), unit=self.unit
         )
 
+    def slice_by_idx(self, slices):
+        """Slice sub IRF from IRF object.
+
+        Parameters
+        ----------
+        slices : dict
+            Dict of axes names and `slice` object pairs. Contains one
+            element for each non-spatial dimension. Axes not specified in the
+            dict are kept unchanged.
+
+        Returns
+        -------
+        sliced : `IRF`
+            Sliced IRF object.
+        """
+        axes = self.axes.slice_by_idx(slices)
+
+        diff = set(self.axes.names).difference(axes.names)
+
+        if diff:
+            diff_slice = {key: value for key, value in slices.items() if key in diff}
+            raise ValueError(f"Integer indexing not supported, got {diff_slice}")
+
+        slices = tuple([slices.get(ax.name, slice(None)) for ax in self.axes])
+        data = self.data[slices]
+        return self.__class__(axes=axes, data=data, unit=self.unit, meta=self.meta)
+
     def is_allclose(self, other, rtol_axes=1e-3, atol_axes=1e-6, **kwargs):
         """Compare two data IRFs for equivalency
 
