@@ -132,6 +132,7 @@ IRF_MAP_HDU_SPECIFICATION = {
     "edisp_kernel_map": "edisp",
     "edisp_map": "edisp",
     "psf_map": "psf",
+    "psf_map_reco": "psf",
 }
 
 
@@ -168,7 +169,8 @@ def load_cta_irfs(filename):
     Access the CTA 1DC IRFs stored in the gammapy datasets
 
     >>> from gammapy.irf import load_cta_irfs
-    >>> cta_irf = load_cta_irfs("$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits")
+    >>> filename = "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
+    >>> cta_irf = load_cta_irfs(filename)
     >>> print(cta_irf['aeff'])
     EffectiveAreaTable2D
     --------------------
