@@ -4,7 +4,7 @@ import astropy.units as u
 from astropy.visualization import quantity_support
 import matplotlib.pyplot as plt
 from matplotlib.ticker import FormatStrFormatter
-from gammapy.maps import Map, MapAxis, MapCoord, WcsGeom
+from gammapy.maps import Map, MapAxes, MapAxis, MapCoord, WcsGeom
 from gammapy.modeling.models import PowerLawSpectralModel
 from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.random import InverseCDFSampler, get_random_state
@@ -12,7 +12,7 @@ from ..core import IRFMap
 from .core import PSF
 from .kernel import PSFKernel
 
-__all__ = ["PSFMap"]
+__all__ = ["PSFMap", "RecoPSFMap"]
 
 
 class IRFLikePSF(PSF):
@@ -43,7 +43,8 @@ class PSFMap(IRFMap):
 
         # Define observation
         pointing = SkyCoord("0d", "0d")
-        irfs = load_cta_irfs("$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits")
+        filename = "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
+        irfs = load_cta_irfs(filename)
         obs = Observation.create(pointing=pointing, irfs=irfs, livetime="1h")
 
         # Create WcsGeom
@@ -72,6 +73,10 @@ class PSFMap(IRFMap):
     def __init__(self, psf_map, exposure_map=None):
         super().__init__(irf_map=psf_map, exposure_map=exposure_map)
 
+    @property
+    def energy_name(self):
+        return self.required_axes[-1]
+
     @property
     def psf_map(self):
         return self._irf_map
@@ -110,8 +115,13 @@ class PSFMap(IRFMap):
         npix_x, npix_y = geom.npix
         axis_lon = MapAxis.from_edges(np.arange(npix_x + 1) - 0.5, name="lon_idx")
         axis_lat = MapAxis.from_edges(np.arange(npix_y + 1) - 0.5, name="lat_idx")
-        return IRFLikePSF(
-            axes=[geom.axes["energy_true"], geom.axes["rad"], axis_lat, axis_lon],
+        axes = MapAxes(
+            [geom.axes[self.energy_name], geom.axes["rad"], axis_lat, axis_lon]
+        )
+        psf = IRFLikePSF
+        psf.required_axes = axes.names
+        return psf(
+            axes=axes,
             data=self.psf_map.data,
             unit=self.psf_map.unit,
         )
@@ -125,7 +135,7 @@ class PSFMap(IRFMap):
         coords_irf = {
             "lon_idx": lon_pix,
             "lat_idx": lat_pix,
-            "energy_true": coords["energy_true"],
+            self.energy_name: coords[self.energy_name],
         }
 
         try:
@@ -155,7 +165,7 @@ class PSFMap(IRFMap):
         if position is None:
             position = self.psf_map.geom.center_skydir
 
-        coords = {"skycoord": position, "rad": rad, "energy_true": energy_true}
+        coords = {"skycoord": position, "rad": rad, self.energy_name: energy_true}
 
         return self.psf_map.integral(axis_name="rad", coords=coords).to("")
 
@@ -179,7 +189,8 @@ class PSFMap(IRFMap):
         if position is None:
             position = self.psf_map.geom.center_skydir
 
-        coords = self._get_irf_coords(energy_true=energy_true, skycoord=position)
+        kwargs = {self.energy_name: energy_true, "skycoord": position}
+        coords = self._get_irf_coords(**kwargs)
 
         return self._psf_irf.containment_radius(fraction, **coords)
 
@@ -189,7 +200,7 @@ class PSFMap(IRFMap):
         Parameters
         ----------
         energy_true : `~astropy.units.Quantity`
-            Energy at which to compute the containment radius
+            Energy true at which to compute the containment radius
         fraction : float
             Containment fraction (range: 0 to 1)
 
@@ -201,9 +212,9 @@ class PSFMap(IRFMap):
         geom = self.psf_map.geom.to_image()
 
         data = self.containment_radius(
-            fraction=fraction,
-            energy_true=energy_true,
-            position=geom.get_coord().skycoord,
+            fraction,
+            energy_true,
+            geom.get_coord().skycoord,
         )
         return Map.from_geom(geom=geom, data=data.value, unit=data.unit)
 
@@ -242,11 +253,13 @@ class PSFMap(IRFMap):
         position = self._get_nearest_valid_position(position)
 
         if max_radius is None:
-            energy_axis = self.psf_map.geom.axes["energy_true"]
-
-            radii = self.containment_radius(
-                fraction=containment, position=position, energy_true=energy_axis.center
-            )
+            energy_axis = self.psf_map.geom.axes[self.energy_name]
+            kwargs = {
+                "fraction": containment,
+                "position": position,
+                self.energy_name: energy_axis.center,
+            }
+            radii = self.containment_radius(**kwargs)
             max_radius = np.max(radii)
 
         geom = geom.to_odd_npix(max_radius=max_radius)
@@ -255,7 +268,7 @@ class PSFMap(IRFMap):
         rad = coords.skycoord.separation(geom.center_skydir)
 
         coords = {
-            "energy_true": coords["energy_true"],
+            self.energy_name: coords[self.energy_name],
             "rad": rad,
             "skycoord": position,
         }
@@ -291,7 +304,7 @@ class PSFMap(IRFMap):
 
         coord = {
             "skycoord": map_coord.skycoord.reshape(-1, 1),
-            "energy_true": map_coord["energy_true"].reshape(-1, 1),
+            self.energy_name: map_coord[self.energy_name].reshape(-1, 1),
             "rad": rad_axis.center,
         }
 
@@ -311,7 +324,7 @@ class PSFMap(IRFMap):
             position_angle=position_angle, separation=separation
         )
         return MapCoord.create(
-            {"skycoord": event_positions, "energy_true": map_coord["energy_true"]}
+            {"skycoord": event_positions, self.energy_name: map_coord[self.energy_name]}
         )
 
     @classmethod
@@ -394,13 +407,13 @@ class PSFMap(IRFMap):
 
         exp_weighed = _map_spectrum_weight(self.exposure_map, spectrum)
         exposure = exp_weighed.sum_over_axes(
-            axes_names=["energy_true"], keepdims=keepdims
+            axes_names=[self.energy_name], keepdims=keepdims
         )
 
         psf_data = exp_weighed.data * self.psf_map.data / exposure.data
         psf_map = Map.from_geom(geom=self.psf_map.geom, data=psf_data, unit="sr-1")
 
-        psf = psf_map.sum_over_axes(axes_names=["energy_true"], keepdims=keepdims)
+        psf = psf_map.sum_over_axes(axes_names=[self.energy_name], keepdims=keepdims)
         return self.__class__(psf_map=psf, exposure_map=exposure)
 
     def plot_containment_radius_vs_energy(
@@ -428,12 +441,11 @@ class PSFMap(IRFMap):
         ax = plt.gca() if ax is None else ax
 
         position = self.psf_map.geom.center_skydir
-        energy_true = self.psf_map.geom.axes["energy_true"].center
+        energy_axis = self.psf_map.geom.axes[self.energy_name]
+        energy_true = energy_axis.center
 
         for frac in fraction:
-            radius = self.containment_radius(
-                energy_true=energy_true, position=position, fraction=frac
-            )
+            radius = self.containment_radius(frac, energy_true, position)
             label = f"Containment: {100 * frac:.1f}%"
             with quantity_support():
                 ax.plot(energy_true, radius, label=label, **kwargs)
@@ -441,7 +453,7 @@ class PSFMap(IRFMap):
         ax.semilogx()
         ax.legend(loc="best")
         ax.yaxis.set_major_formatter(FormatStrFormatter("%.2f"))
-        ax.set_xlabel(f"Energy ({ax.xaxis.units})")
+        energy_axis.format_plot_xaxis(ax=ax)
         ax.set_ylabel(f"Containment radius ({ax.yaxis.units})")
         return ax
 
@@ -454,7 +466,7 @@ class PSFMap(IRFMap):
         ----------
         ax : `~matplotlib.pyplot.Axes`
             Axes to plot on.
-        energy_true : `~astropy.units.Quantity`
+        energy : `~astropy.units.Quantity`
             Energies where to plot the PSF.
         **kwargs : dict
             Keyword arguments pass to `~matplotlib.pyplot.plot`.
@@ -473,7 +485,7 @@ class PSFMap(IRFMap):
             psf_value = self.psf_map.interp_by_coord(
                 {
                     "skycoord": self.psf_map.geom.center_skydir,
-                    "energy_true": value,
+                    self.energy_name: value,
                     "rad": rad,
                 }
             )
@@ -523,6 +535,136 @@ class PSFMap(IRFMap):
         self.exposure_map.reduce_over_axes().plot(ax=axes[2], add_cbar=True)
 
         axes[3].set_title("Containment radius at 1 TeV")
-        self.containment_radius_map(energy_true=2 * u.TeV).plot(
-            ax=axes[3], add_cbar=True
+        kwargs = {self.energy_name: 1 * u.TeV}
+        self.containment_radius_map(**kwargs).plot(ax=axes[3], add_cbar=True)
+
+
+class RecoPSFMap(PSFMap):
+    """Class containing the Map of PSFs in reconstructed energy and allowing to interact with it.
+
+    Parameters
+    ----------
+    psf_map : `~gammapy.maps.Map`
+        the input PSF Map. Should be a Map with 2 non spatial axes.
+        rad and energy axes should be given in this specific order.
+    exposure_map : `~gammapy.maps.Map`
+        Associated exposure map. Needs to have a consistent map geometry.
+    """
+
+    tag = "psf_map_reco"
+    required_axes = ["rad", "energy"]
+
+    @property
+    def energy_name(self):
+        return self.required_axes[-1]
+
+    @classmethod
+    def from_gauss(cls, energy_axis, rad_axis=None, sigma=0.1 * u.deg, geom=None):
+        """Create all -sky PSF map from Gaussian width.
+
+        This is used for testing and examples.
+
+        The width can be the same for all energies
+        or be an array with one value per energy node.
+        It does not depend on position.
+
+        Parameters
+        ----------
+        energy_axis : `~gammapy.maps.MapAxis`
+            Energy axis.
+        rad_axis : `~gammapy.maps.MapAxis`
+            Offset angle wrt source position axis.
+        sigma : `~astropy.coordinates.Angle`
+            Gaussian width.
+        geom : `Geom`
+            Image geometry. By default an allsky geometry is created.
+
+        Returns
+        -------
+        psf_map : `PSFMap`
+            Point spread function map.
+        """
+        return super().from_gauss(energy_axis, rad_axis, sigma, geom)
+
+    def containment(self, rad, energy, position=None):
+        """Containment at given coords
+
+        Parameters
+        ----------
+        rad : `~astropy.units.Quantity`
+            Rad value
+        energy : `~astropy.units.Quantity`
+            Energy value
+        position : `~astropy.coordinates.SkyCoord`
+            Sky position. By default the center of the map is chosen
+
+        Returns
+        -------
+        containment : `~astropy.units.Quantity`
+            Containment values
+        """
+        return super().containment(rad, energy, position)
+
+    def containment_radius(self, fraction, energy, position=None):
+        """Containment at given coords
+
+        Parameters
+        ----------
+        fraction : float
+            Containment fraction
+        energy : `~astropy.units.Quantity`
+            Energy value
+        position : `~astropy.coordinates.SkyCoord`
+            Sky position. By default the center of the map is chosen
+
+        Returns
+        -------
+        containment : `~astropy.units.Quantity`
+            Containment values
+        """
+        return super().containment_radius(fraction, energy, position)
+
+    def containment_radius_map(self, energy, fraction=0.68):
+        """Containment radius map.
+
+        Parameters
+        ----------
+        energy : `~astropy.units.Quantity`
+            Energy at which to compute the containment radius
+        fraction : float
+            Containment fraction (range: 0 to 1)
+
+        Returns
+        -------
+        containment_radius_map : `~gammapy.maps.Map`
+            Containment radius map
+        """
+        return super().containment_radius_map(energy, fraction=0.68)
+
+    def plot_psf_vs_rad(self, ax=None, energy=[0.1, 1, 10] * u.TeV, **kwargs):
+        """Plot PSF vs radius.
+
+        The method plots the profile at the center of the map.
+
+        Parameters
+        ----------
+        ax : `~matplotlib.pyplot.Axes`
+            Axes to plot on.
+        energy : `~astropy.units.Quantity`
+            Energies where to plot the PSF.
+        **kwargs : dict
+            Keyword arguments pass to `~matplotlib.pyplot.plot`.
+
+        Returns
+        -------
+        ax : `~matplotlib.pyplot.Axes`
+             Axes to plot on.
+
+        """
+        return super().plot_psf_vs_rad(ax, energy_true=energy, **kwargs)
+
+    def stack(self, other, weights=None, nan_to_num=True):
+        """Stack IRF map with another one in place."""
+        raise NotImplementedError(
+            "Stacking is not supported for PSF in reconstructed energy."
         )
