@@ -383,6 +383,11 @@ class ReflectedRegionsFinder(RegionsFinder):
         wcs: `~astropy.wcs.WCS`
             WCS for the determined regions
         """
+        if isinstance(region, PointSkyRegion):
+            raise TypeError(
+                "ReflectedRegionsFinder does not work with PointSkyRegion. Use WobbleRegionsFinder instead."
+            )
+
         regions = []
 
         reference_geom = self._create_reference_geometry(region, center)
@@ -420,7 +425,7 @@ class ReflectedRegionsBackgroundMaker(Maker):
 
     Attributes
     ----------
-    regions_finder: RegionsFinder
+    region_finder: RegionsFinder
         if not given, a `ReflectedRegionsFinder` will be created and
         any of the ``**kwargs`` will be forwarded to the `ReflectedRegionsFinder`.
     exclusion_mask : `~gammapy.maps.WcsNDMap`, optional
@@ -501,7 +506,8 @@ class ReflectedRegionsBackgroundMaker(Maker):
             rad_max=rad_max, geom=geom
         ):
             raise ValueError(
-                "Must use `PointSkyRegion` or `CircleSkyRegion` with rad max equivalent radius in point-like analysis,"
+                "Must use `PointSkyRegion` or `CircleSkyRegion` with rad max "
+                "equivalent radius in point-like analysis,"
                 f" got {type(geom.region)} instead"
             )
 
@@ -572,6 +578,7 @@ class ReflectedRegionsBackgroundMaker(Maker):
         if dataset_onoff.counts_off is None:
             dataset_onoff.mask_safe.data[...] = False
             log.warning(
-                f"ReflectedRegionsBackgroundMaker failed. Setting {dataset_onoff.name} mask to False."
+                f"ReflectedRegionsBackgroundMaker failed. Setting {dataset_onoff.name} "
+                "mask to False."
             )
         return dataset_onoff
