@@ -3,7 +3,8 @@ import logging
 import astropy.units as u
 from astropy.table import Table
 from regions import PointSkyRegion
-from gammapy.irf import EDispKernelMap, PSFMap
+from gammapy.data.pointing import PointingMode
+from gammapy.irf import EDispKernelMap, PSFMap, RecoPSFMap
 from gammapy.maps import Map
 from .core import Maker
 from .utils import (
@@ -34,6 +35,10 @@ class MapDatasetMaker(Maker):
     background_interp_missing_data: bool
         Interpolate missing values in background 3d map.
         Default is True, have to be set to True for CTA IRF.
+    background_pad_offset: bool
+        Pad one bin in offset for 2d background map.
+        This avoid extrapolation at edges and use the nearest value.
+        Default is True.
 
     Examples
     --------
@@ -51,7 +56,14 @@ class MapDatasetMaker(Maker):
     >>> #prepare the geom
     >>> energy_axis = MapAxis.from_energy_bounds(1.0, 10.0, 4, unit="TeV")
     >>> energy_axis_true = MapAxis.from_energy_bounds( 0.5, 20, 10, unit="TeV", name="energy_true")
-    >>> geom = WcsGeom.create(skydir=(83.633, 22.014), binsz=0.02, width=(2, 2), frame="icrs", proj="CAR", axes=[energy_axis])
+    >>> geom = WcsGeom.create(
+            skydir=(83.633, 22.014),
+            binsz=0.02,
+            width=(2, 2),
+            frame="icrs",
+            proj="CAR",
+            axes=[energy_axis],
+        )
 
     >>> #Run the maker
     >>> empty = MapDataset.create(geom=geom, energy_axis_true=energy_axis_true, name="empty")
@@ -94,9 +106,11 @@ class MapDatasetMaker(Maker):
         selection=None,
         background_oversampling=None,
         background_interp_missing_data=True,
+        background_pad_offset=True,
     ):
         self.background_oversampling = background_oversampling
         self.background_interp_missing_data = background_interp_missing_data
+        self.background_pad_offset = background_pad_offset
         if selection is None:
             selection = self.available_selection
 
@@ -215,6 +229,9 @@ class MapDatasetMaker(Maker):
         if self.background_interp_missing_data:
             bkg.interp_missing_data(axis_name="energy")
 
+        if self.background_pad_offset and bkg.has_offset_axis:
+            bkg = bkg.pad(1, mode="edge", axis_name="offset")
+
         return make_map_background_irf(
             pointing=observation.fixed_pointing_info,
             ontime=observation.observation_time_duration,
@@ -300,9 +317,10 @@ class MapDatasetMaker(Maker):
         """
         psf = observation.psf
 
-        if isinstance(psf, PSFMap):
+        if isinstance(psf, RecoPSFMap):
+            return RecoPSFMap(psf.psf_map.interp_to_geom(geom))
+        elif isinstance(psf, PSFMap):
             return PSFMap(psf.psf_map.interp_to_geom(geom))
-
         exposure = self.make_exposure_irf(geom.squash(axis_name="rad"), observation)
 
         return make_psf_map(
@@ -328,8 +346,19 @@ class MapDatasetMaker(Maker):
         meta_table = Table()
         meta_table["TELESCOP"] = [observation.aeff.meta.get("TELESCOP", "Unknown")]
         meta_table["OBS_ID"] = [observation.obs_id]
-        meta_table["RA_PNT"] = [observation.pointing_radec.icrs.ra.deg] * u.deg
-        meta_table["DEC_PNT"] = [observation.pointing_radec.icrs.dec.deg] * u.deg
+
+        if observation.fixed_pointing_info.mode == PointingMode.POINTING:
+            meta_table["OBS_MODE"] = "POINTING"
+            meta_table["RA_PNT"] = [observation.pointing_radec.icrs.ra.deg] * u.deg
+            meta_table["DEC_PNT"] = [observation.pointing_radec.icrs.dec.deg] * u.deg
+        elif observation.fixed_pointing_info.mode == PointingMode.DRIFT:
+            meta_table["OBS_MODE"] = "DRIFT"
+            meta_table["ALT_PNT"] = [
+                observation.fixed_pointing_info.fixed_altaz.alt.deg
+            ] * u.deg
+            meta_table["AZ_PNT"] = [
+                observation.fixed_pointing_info.fixed_altaz.az.deg
+            ] * u.deg
 
         return meta_table
 
