@@ -90,10 +90,10 @@ class MapAxis:
         Axis name
     node_type : str
         Flag indicating whether coordinate nodes correspond to pixel
-        edges (node_type = 'edge') or pixel centers (node_type =
+        edges (node_type = 'edges') or pixel centers (node_type =
         'center').  'center' should be used where the map values are
         defined at a specific coordinate (e.g. differential
-        quantities). 'edge' should be used where map values are
+        quantities). 'edges' should be used where map values are
         defined by an integral over coordinate intervals (e.g. a
         counts histogram).
     unit : str
@@ -102,7 +102,9 @@ class MapAxis:
 
     # TODO: Cache an interpolation object?
     def __init__(self, nodes, interp="lin", name="", node_type="edges", unit=""):
-        self._name = name
+
+        if not isinstance(name, str):
+            raise TypeError(f"Name must be a string, got: {type(name)!r}")
 
         if len(nodes) != len(np.unique(nodes)):
             raise ValueError("MapAxis: node values must be unique")
@@ -116,6 +118,7 @@ class MapAxis:
         else:
             nodes = np.array(nodes)
 
+        self._name = name
         self._unit = u.Unit(unit)
         self._nodes = nodes.astype(float)
         self._node_type = node_type
@@ -313,7 +316,7 @@ class MapAxis:
         return mpl_scale[self.interp]
 
     def to_node_type(self, node_type):
-        """Return MapAxis copy chaning its node type to node_type.
+        """Return MapAxis copy changing its node type to node_type.
 
         Parameters
         ----------
@@ -340,6 +343,21 @@ class MapAxis:
                 unit=self.unit,
             )
 
+    def rename(self, new_name):
+        """Rename the axis.
+
+        Parameters
+        ----------
+        new_name : str
+            The new name for the axis.
+
+        Returns
+        -------
+        axis : `~gammapy.maps.MapAxis`
+            Renamed MapAxis
+        """
+        return self.copy(name=new_name)
+
     def format_plot_xaxis(self, ax):
         """Format plot axis
 
@@ -426,7 +444,7 @@ class MapAxis:
 
     @property
     def node_type(self):
-        """Return node type ('center' or 'edge')."""
+        """Return node type ('center' or 'edges')."""
         return self._node_type
 
     @property
@@ -438,7 +456,7 @@ class MapAxis:
     def from_bounds(cls, lo_bnd, hi_bnd, nbin, **kwargs):
         """Generate an axis object from a lower/upper bound and number of bins.
 
-        If node_type = 'edge' then bounds correspond to the
+        If node_type = 'edges' then bounds correspond to the
         lower and upper bound of the first and last bin.  If node_type
         = 'center' then bounds correspond to the centers of the first
         and last bin.
@@ -1096,7 +1114,7 @@ class MapAxis:
     def to_table(self, format="ogip"):
         """Convert `~astropy.units.Quantity` to OGIP ``EBOUNDS`` extension.
 
-        See https://heasarc.gsfc.nasa.gov/docs/heasarc/caldb/docs/memos/cal_gen_92_002/cal_gen_92_002.html#tth_sEc3.2
+        See https://heasarc.gsfc.nasa.gov/docs/heasarc/caldb/docs/memos/cal_gen_92_002/cal_gen_92_002.html#tth_sEc3.2  # noqa: E501
 
         The 'ogip-sherpa' format is equivalent to 'ogip' but uses keV energy units.
 
@@ -1170,7 +1188,7 @@ class MapAxis:
     def to_table_hdu(self, format="ogip"):
         """Convert `~astropy.units.Quantity` to OGIP ``EBOUNDS`` extension.
 
-        See https://heasarc.gsfc.nasa.gov/docs/heasarc/caldb/docs/memos/cal_gen_92_002/cal_gen_92_002.html#tth_sEc3.2
+        See https://heasarc.gsfc.nasa.gov/docs/heasarc/caldb/docs/memos/cal_gen_92_002/cal_gen_92_002.html#tth_sEc3.2  # noqa: E501
 
         The 'ogip-sherpa' format is equivalent to 'ogip' but uses keV energy units.
 
@@ -1826,7 +1844,7 @@ class MapAxes(Sequence):
 
         Parameters
         ----------
-        format : {"gadf", "gadf-dl3", "fgst-ccube", "fgst-template", "ogip", "ogip-sherpa", "ogip-arf", "ogip-arf-sherpa"}
+        format : {"gadf", "gadf-dl3", "fgst-ccube", "fgst-template", "ogip", "ogip-sherpa", "ogip-arf", "ogip-arf-sherpa"}  # noqa E501
             Format to use.
 
         Returns
@@ -2044,6 +2062,30 @@ class MapAxes(Sequence):
         except ValueError:
             raise ValueError(message)
 
+    def rename_axes(self, names, new_names):
+        """Rename the axes.
+
+        Parameters
+        ----------
+        names : list or str
+            Names of the axes
+        new_names : list or str
+            New names of the axes (list must be of same length than `names`).
+
+        Returns
+        -------
+        axes : `MapAxes`
+            Renamed Map axes object
+        """
+        axes = self.copy()
+        if isinstance(names, str):
+            names = [names]
+        if isinstance(new_names, str):
+            new_names = [new_names]
+        for name, new_name in zip(names, new_names):
+            axes[name]._name = new_name
+        return axes
+
     @property
     def center_coord(self):
         """Center coordinates"""
@@ -2760,12 +2802,12 @@ class LabelMapAxis:
     node_type = "label"
 
     def __init__(self, labels, name=""):
-        unique_labels = set(labels)
+        unique_labels = np.unique(labels)
 
         if not len(unique_labels) == len(labels):
             raise ValueError("Node labels must be unique")
 
-        self._labels = np.array(labels)
+        self._labels = unique_labels
         self._name = name
 
     @property
