@@ -51,7 +51,8 @@ class HpxGeom(Geom):
         either a single nside value or a vector of nside values
         defining the pixel size for each image plane.  If nside is not
         a scalar then its dimensionality should match that of the
-        non-spatial axes.
+        non-spatial axes. If nest is True, nside must be a power of 2,
+        less than 2**30.
     nest : bool
         True -> 'NESTED', False -> 'RING' indexing scheme
     frame : str
@@ -70,8 +71,9 @@ class HpxGeom(Geom):
     is_region = False
 
     def __init__(self, nside, nest=True, frame="icrs", region=None, axes=None):
+        from healpy.pixelfunc import check_nside
 
-        # FIXME: Require NSIDE to be power of two when nest=True
+        check_nside(nside, nest=nest)
 
         self._nside = np.array(nside, ndmin=1)
         self._axes = MapAxes.from_default(axes, n_spatial_axes=1)
@@ -83,9 +85,8 @@ class HpxGeom(Geom):
                 "with the axes argument."
             )
 
-        self._nest = nest
         self._frame = frame
-
+        self._nest = nest
         self._ipix = None
         self._region = region
         self._create_lookup(region)
@@ -807,7 +808,8 @@ class HpxGeom(Geom):
         ----------
         nside : int or `~numpy.ndarray`
             HEALPix NSIDE parameter.  This parameter sets the size of
-            the spatial pixels in the map.
+            the spatial pixels in the map. If nest is True, nside must be a
+            power of 2, less than 2**30.
         binsz : float or `~numpy.ndarray`
             Approximate pixel size in degrees.  An NSIDE will be
             chosen that corresponds to a pixel size closest to this
@@ -838,10 +840,10 @@ class HpxGeom(Geom):
         --------
         >>> from gammapy.maps import HpxGeom, MapAxis
         >>> axis = MapAxis.from_bounds(0,1,2)
-        >>> geom = HpxGeom.create(nside=16)
-        >>> geom = HpxGeom.create(binsz=0.1, width=10.0)
-        >>> geom = HpxGeom.create(nside=64, width=10.0, axes=[axis])
-        >>> geom = HpxGeom.create(nside=[32,64], width=10.0, axes=[axis])
+        >>> geom = HpxGeom.create(nside=16) # doctest: +SKIP
+        >>> geom = HpxGeom.create(binsz=0.1, width=10.0) # doctest: +SKIP
+        >>> geom = HpxGeom.create(nside=64, width=10.0, axes=[axis]) # doctest: +SKIP
+        >>> geom = HpxGeom.create(nside=[32,64], width=10.0, axes=[axis]) # doctest: +SKIP
         """
         if nside is None and binsz is None:
             raise ValueError("Either nside or binsz must be defined.")
