@@ -1,4 +1,5 @@
 import copy
+import logging
 from functools import lru_cache
 import numpy as np
 from astropy import units as u
@@ -28,7 +29,8 @@ from gammapy.utils.regions import (
 )
 from gammapy.visualization.utils import ARTIST_TO_LINE_PROPERTIES
 from ..axes import MapAxes
-from ..core import Map, MapCoord
+from ..coord import MapCoord
+from ..core import Map
 from ..geom import Geom, pix_tuple_to_idx
 from ..utils import _check_width
 from ..wcs import WcsGeom
@@ -70,7 +72,7 @@ class RegionGeom(Geom):
     def __init__(self, region, axes=None, wcs=None, binsz_wcs="0.1 deg"):
         self._region = region
         self._axes = MapAxes.from_default(axes, n_spatial_axes=2)
-        self._binsz_wcs = binsz_wcs
+        self._binsz_wcs = u.Quantity(binsz_wcs)
 
         if wcs is None and region is not None:
             if isinstance(region, CompoundSkyRegion):
@@ -206,6 +208,8 @@ class RegionGeom(Geom):
         """Check if a given map coordinate is contained in the region.
         Requires the `.region` attribute to be set.
 
+        For `PointSkyRegion` the method always returns true.
+
         Parameters
         ----------
         coords : tuple, dict, `MapCoord` or `~astropy.coordinates.SkyCoord`
@@ -222,11 +226,17 @@ class RegionGeom(Geom):
             raise ValueError("Region definition required.")
 
         coords = MapCoord.create(coords, frame=self.frame, axis_names=self.axes.names)
+
+        if self.is_all_point_sky_regions:
+            return np.ones(coords.skycoord.shape, dtype=bool)
+
         return self.region.contains(coords.skycoord, self.wcs)
 
     def contains_wcs_pix(self, pix):
         """Check if a given wcs pixel coordinate is contained in the region.
 
+        For `PointSkyRegion` the method always returns true.
+
         Parameters
         ----------
         pix : tuple
@@ -237,6 +247,9 @@ class RegionGeom(Geom):
         containment : `~numpy.ndarray`
             Bool array.
         """
+        if self.is_all_point_sky_regions:
+            return np.ones(pix[0].shape, dtype=bool)
+
         region_pix = self.region.to_pixel(self.wcs)
         return region_pix.contains(PixCoord(pix[0], pix[1]))
 
@@ -323,7 +336,7 @@ class RegionGeom(Geom):
             raise ValueError("Region definition required.")
 
         # compound regions do not implement area()
-        # so we use the mask represenation and estimate the area
+        # so we use the mask representation and estimate the area
         # from the pixels in the mask using oversampling
         if isinstance(self.region, CompoundSkyRegion):
             # oversample by a factor of ten
@@ -513,19 +526,21 @@ class RegionGeom(Geom):
         return tuple(idxs)
 
     def coord_to_pix(self, coords):
+        # inherited docstring
+        if isinstance(coords, tuple) and len(coords) == len(self.axes):
+            skydir = self.center_skydir.transform_to(self.frame)
+            coords = (skydir.data.lon, skydir.data.lat) + coords
+        elif isinstance(coords, dict):
+            valid_keys = ["lon", "lat", "skycoord"]
+            if not any([_ in coords for _ in valid_keys]):
+                coords.setdefault("skycoord", self.center_skydir)
+
         coords = MapCoord.create(coords, frame=self.frame, axis_names=self.axes.names)
 
         if self.region is None:
             pix = (0, 0)
         else:
-            # TODO: remove once fix is available in regions
-            if isinstance(self.region, PointSkyRegion):
-                point_region = self.region.to_pixel(self.wcs)
-                point_region.meta["include"] = False
-                pix_coord = PixCoord.from_sky(coords.skycoord, self.wcs)
-                in_region = point_region.contains(pix_coord)
-            else:
-                in_region = self.region.contains(coords.skycoord, wcs=self.wcs)
+            in_region = self.contains(coords.skycoord)
 
             x = np.zeros(coords.skycoord.shape)
             x[~in_region] = np.nan
@@ -700,6 +715,8 @@ class RegionGeom(Geom):
             regions = [regions]
         elif isinstance(regions, SkyCoord):
             regions = [PointSkyRegion(center=regions)]
+        elif isinstance(regions, list) and len(regions) == 0:
+            regions = None
 
         if regions:
             regions = regions_to_compound_region(regions)
@@ -794,37 +811,40 @@ class RegionGeom(Geom):
         ax : `~astropy.visualization.WCSAxes`
             Axes to plot on.
         """
-        kwargs_point = kwargs_point or {}
+        if self.region:
+            kwargs_point = kwargs_point or {}
 
-        if ax is None:
-            ax = plt.gca()
+            if ax is None:
+                ax = plt.gca()
 
-            if not isinstance(ax, WCSAxes):
-                ax.remove()
-                wcs_geom = self.to_wcs_geom()
-                m = Map.from_geom(geom=wcs_geom.to_image())
-                ax = m.plot(add_cbar=False, vmin=-1, vmax=0)
+                if not isinstance(ax, WCSAxes):
+                    ax.remove()
+                    wcs_geom = self.to_wcs_geom()
+                    m = Map.from_geom(geom=wcs_geom.to_image())
+                    ax = m.plot(add_cbar=False, vmin=-1, vmax=0)
 
-        kwargs.setdefault("facecolor", "None")
-        kwargs.setdefault("edgecolor", "tab:blue")
-        kwargs_point.setdefault("marker", "*")
+            kwargs.setdefault("facecolor", "None")
+            kwargs.setdefault("edgecolor", "tab:blue")
+            kwargs_point.setdefault("marker", "*")
 
-        for key, value in kwargs.items():
-            key_point = ARTIST_TO_LINE_PROPERTIES.get(key, None)
-            if key_point:
-                kwargs_point[key_point] = value
+            for key, value in kwargs.items():
+                key_point = ARTIST_TO_LINE_PROPERTIES.get(key, None)
+                if key_point:
+                    kwargs_point[key_point] = value
 
-        for region in compound_region_to_regions(self.region):
-            region_pix = region.to_pixel(wcs=ax.wcs)
+            for region in compound_region_to_regions(self.region):
+                region_pix = region.to_pixel(wcs=ax.wcs)
 
-            if isinstance(region, PointSkyRegion):
-                artist = region_pix.as_artist(**kwargs_point)
-            else:
-                artist = region_pix.as_artist(**kwargs)
+                if isinstance(region, PointSkyRegion):
+                    artist = region_pix.as_artist(**kwargs_point)
+                else:
+                    artist = region_pix.as_artist(**kwargs)
 
-            if path_effect:
-                artist.add_path_effect(path_effect)
+                if path_effect:
+                    artist.add_path_effect(path_effect)
 
-            ax.add_artist(artist)
+                ax.add_artist(artist)
 
-        return ax
+            return ax
+        else:
+            logging.info("Region definition required.")
