@@ -70,6 +70,11 @@ def test_mapaxis_repr():
     assert "MapAxis" in repr(axis)
 
 
+def test_mapaxis_invalid_name():
+    with pytest.raises(TypeError):
+        MapAxis([1, 2, 3], name=1)
+
+
 @pytest.mark.parametrize(
     ("nodes", "interp", "node_type", "unit", "name", "result"),
     MAP_AXIS_NODE_TYPE_UNIT,
@@ -282,6 +287,19 @@ def test_map_axes_pad():
     assert_allclose(axes["energy"].edges, [0.1, 1, 10, 100] * u.TeV)
 
 
+def test_rename():
+    axis_1 = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=1)
+    axis = axis_1.rename("energy_true")
+    assert axis_1.name == "energy"
+    assert axis.name == "energy_true"
+
+    axis_2 = MapAxis.from_bounds(0, 1, nbin=2, unit="deg", name="rad")
+
+    axes = MapAxes([axis_1, axis_2])
+    axes = axes.rename_axes(["energy", "rad"], ["energy_true", "angle"])
+    assert axes.names == ["energy_true", "angle"]
+
+
 @pytest.mark.parametrize(("edges", "interp"), MAP_AXIS_INTERP)
 def test_mapaxis_init_from_edges(edges, interp):
     axis = MapAxis(edges, interp=interp)
