@@ -491,7 +491,74 @@ def test_map_plot_mask():
         mask.plot_mask()
 
 
-def test_resample_wcs_wcs():
+def test_reproject_2d():
+    npix1 = 3
+    geom1 = WcsGeom.create(npix=npix1, frame="icrs")
+    geom1_large = WcsGeom.create(npix=npix1 + 5, frame="icrs")
+    map1 = Map.from_geom(geom1, data=np.eye(npix1), unit="s")
+
+    factor = 10
+    binsz = 0.5 / factor
+    npix2 = 7 * factor
+    geom2 = WcsGeom.create(
+        skydir=SkyCoord(0.1, 0.1, unit=u.deg), binsz=binsz, npix=npix2, frame="galactic"
+    )
+
+    map1_repro = map1.reproject_to_geom(geom2, preserve_counts=True)
+    assert map1_repro.unit == map1.unit
+    assert_allclose(np.sum(map1_repro), np.sum(map1), rtol=1e-5)
+    map1_new = map1_repro.reproject_to_geom(geom1_large, preserve_counts=True)
+    assert_allclose(np.sum(map1_repro), np.sum(map1_new), rtol=1e-5)
+
+    map1_repro = map1.reproject_to_geom(geom2, preserve_counts=False)
+    map1_new = map1_repro.reproject_to_geom(geom1_large, preserve_counts=False)
+    assert_allclose(
+        np.sum(map1_repro * geom2.solid_angle()),
+        np.sum(map1_new * geom1_large.solid_angle()),
+        rtol=1e-3,
+    )
+
+    factor = 0.5
+    binsz = 0.5 / factor
+    npix = 7
+    geom2 = WcsGeom.create(
+        skydir=SkyCoord(0.1, 0.1, unit=u.deg), binsz=binsz, npix=npix, frame="galactic"
+    )
+    geom1_large = WcsGeom.create(npix=npix1 + 5, frame="icrs")
+
+    map1_repro = map1.reproject_to_geom(geom2, preserve_counts=True)
+    assert_allclose(np.sum(map1_repro), np.sum(map1), rtol=1e-5)
+    map1_new = map1_repro.reproject_to_geom(geom1_large, preserve_counts=True)
+    assert_allclose(np.sum(map1_repro), np.sum(map1_new), rtol=1e-3)
+
+    map1_repro = map1.reproject_to_geom(geom2, preserve_counts=False)
+    map1_new = map1_repro.reproject_to_geom(geom1_large, preserve_counts=False)
+    assert_allclose(
+        np.sum(map1_repro * geom2.solid_angle()),
+        np.sum(map1_new * geom1_large.solid_angle()),
+        rtol=1e-3,
+    )
+
+
+def test_resample_wcs_Wcs():
+    npix1 = 3
+    geom1 = WcsGeom.create(npix=npix1, frame="icrs")
+    map1 = Map.from_geom(geom1, data=np.eye(npix1), unit="1 / (GeV m2 s sr)")
+
+    geom2 = WcsGeom.create(
+        skydir=SkyCoord(0.0, 0.0, unit=u.deg), binsz=0.5, npix=7, frame="galactic"
+    )
+
+    map2 = map1.resample(geom2, preserve_counts=False)
+    assert_allclose(
+        np.sum(map2 * geom2.solid_angle()),
+        np.sum(map1 * geom1.solid_angle()),
+        rtol=1e-3,
+    )
+    assert map2.unit == map1.unit
+
+
+def test_resample_weights():
     npix1 = 3
     geom1 = WcsGeom.create(npix=npix1, frame="icrs")
     map1 = Map.from_geom(geom1, data=np.eye(npix1))
@@ -499,28 +566,167 @@ def test_resample_wcs_wcs():
     geom2 = WcsGeom.create(
         skydir=SkyCoord(0.0, 0.0, unit=u.deg), binsz=0.5, npix=7, frame="galactic"
     )
-    map2 = Map.from_geom(geom2)
-    map2.resample(geom1, weights=map1.quantity, preserve_counts=False)
-    assert_allclose(
-        np.sum(map2 * geom2.solid_angle()),
-        np.sum(map1 * geom1.solid_angle()),
-        rtol=1e-3,
+
+    map2 = map1.resample(geom2, weights=np.zeros(npix1), preserve_counts=False)
+    assert np.sum(map2.data) == 0.0
+
+
+def test_resample_downsample_wcs():
+    geom_fine = WcsGeom.create(npix=(15, 15), frame="icrs")
+    map_fine = Map.from_geom(geom_fine)
+    map_fine.data = np.arange(225).reshape((15, 15))
+
+    map_downsampled = map_fine.downsample(3)
+    map_resampled = map_fine.resample(geom_fine.downsample(3), preserve_counts=True)
+
+    assert_allclose(map_downsampled, map_resampled, rtol=1e-5)
+
+
+def test_resample_downsample_axis():
+    axis = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=12)
+    geom_fine = WcsGeom.create(npix=(3, 3), frame="icrs", axes=[axis])
+    map_fine = Map.from_geom(geom_fine)
+    map_fine.data = np.arange(108).reshape((12, 3, 3))
+
+    map_downsampled = map_fine.downsample(3, axis_name="energy", preserve_counts=False)
+    map_resampled = map_fine.resample(
+        geom_fine.downsample(3, axis_name="energy"), preserve_counts=False
     )
 
+    assert_allclose(map_downsampled, map_resampled, rtol=1e-5)
+
 
 def test_resample_wcs_hpx():
     geom1 = HpxGeom.create(nside=32, frame="icrs")
-    map1 = Map.from_geom(geom1, data=1.0)
+    map1 = Map.from_geom(geom1, data=1.0, unit="1 / (GeV m2 s sr)")
     geom2 = HpxGeom.create(
         skydir=SkyCoord(0.0, 0.0, unit=u.deg), nside=8, frame="galactic"
     )
-    map2 = Map.from_geom(geom2)
-    map2.resample(geom1, weights=map1.quantity, preserve_counts=False)
+
+    map2 = map1.resample(geom2, weights=map1.quantity, preserve_counts=False)
     assert_allclose(
         np.sum(map2 * geom2.solid_angle()),
         np.sum(map1 * geom1.solid_angle()),
         rtol=1e-3,
     )
+    assert map2.unit == map1.unit
+
+
+def test_map_reproject_wcs_to_hpx():
+    axis = MapAxis.from_bounds(
+        1.0, 10.0, 3, interp="log", name="energy", node_type="center"
+    )
+    axis2 = MapAxis.from_bounds(
+        1.0, 10.0, 8, interp="log", name="energy", node_type="center"
+    )
+    geom_wcs = WcsGeom.create(
+        skydir=(0, 0), npix=(11, 11), binsz=10, axes=[axis], frame="galactic"
+    )
+    geom_hpx = HpxGeom.create(binsz=10, frame="galactic", axes=[axis2])
+
+    data = np.arange(11 * 11 * 3).reshape(geom_wcs.data_shape)
+    m = WcsNDMap(geom_wcs, data=data)
+
+    m_r = m.reproject_to_geom(geom_hpx.to_image())
+    actual = m_r.get_by_coord({"lon": 0, "lat": 0, "energy": [1.0, 3.16227766, 10.0]})
+    assert_allclose(actual, [65.0, 186.0, 307.0], rtol=1e-3)
+
+    with pytest.raises(TypeError):
+        m.reproject_to_geom(geom_hpx)
+
+
+def test_map_reproject_hpx_to_wcs():
+    axis = MapAxis.from_bounds(
+        1.0, 10.0, 3, interp="log", name="energy", node_type="center"
+    )
+    axis2 = MapAxis.from_bounds(
+        1.0, 10.0, 8, interp="log", name="energy", node_type="center"
+    )
+    geom_wcs = WcsGeom.create(
+        skydir=(0, 0), npix=(11, 11), binsz=10, axes=[axis], frame="galactic"
+    )
+    geom_wcs2 = WcsGeom.create(
+        skydir=(0, 0), npix=(11, 11), binsz=10, axes=[axis2], frame="galactic"
+    )
+    geom_hpx = HpxGeom.create(binsz=10, frame="galactic", axes=[axis])
+
+    data = np.arange(3 * 768).reshape(geom_hpx.data_shape)
+    m = HpxNDMap(geom_hpx, data=data)
+
+    m_r = m.reproject_to_geom(geom_wcs.to_image())
+    actual = m_r.get_by_coord({"lon": 0, "lat": 0, "energy": [1.0, 3.16227766, 10.0]})
+    assert_allclose(actual, [287.5, 1055.5, 1823.5], rtol=1e-3)
+
+    m_r = m.reproject_to_geom(geom_wcs)
+    actual = m_r.get_by_coord({"lon": 0, "lat": 0, "energy": [1.0, 3.16227766, 10.0]})
+    assert_allclose(actual, [287.5, 1055.5, 1823.5], rtol=1e-3)
+
+    with pytest.raises(TypeError):
+        m.reproject_to_geom(geom_wcs2)
+
+
+def test_map_reproject_wcs_to_wcs_with_axes():
+    energy_nodes = np.arange(4) - 0.5
+    time_nodes = np.arange(5) - 0.5
+
+    axis1 = MapAxis(energy_nodes, interp="lin", name="energy", node_type="edges")
+    axis2 = MapAxis(time_nodes, interp="lin", name="time", node_type="edges")
+    geom_wcs_1 = WcsGeom.create(
+        skydir=(266.405, -28.936),
+        npix=(11, 11),
+        binsz=0.1,
+        axes=[axis1, axis2],
+        frame="icrs",
+    )
+    geom_wcs_2 = WcsGeom.create(
+        skydir=(0, 0), npix=(11, 11), binsz=0.1, frame="galactic"
+    )
+
+    spatial_data = np.zeros((11, 11))
+    energy_data = axis1.center.reshape(3, 1, 1)
+    time_data = axis2.center.reshape(4, 1, 1, 1)
+    data = spatial_data + energy_data + 0.5 * time_data
+    m = WcsNDMap(geom_wcs_1, data=data)
+
+    m_r = m.reproject_to_geom(geom_wcs_2)
+    assert m.data.shape == m_r.data.shape
+
+    geom_wcs_3 = geom_wcs_1.copy(axes=[axis1, axis2])
+    m_r_3 = m.reproject_to_geom(geom_wcs_3, preserve_counts=False)
+    for data, idx in m_r_3.iter_by_image_data():
+        ref = idx[1] + 0.5 * idx[0]
+        if np.any(data > 0):
+            assert_allclose(np.nanmean(data[data > 0]), ref)
+
+    factor = 2
+    axis1_up = axis1.upsample(factor=factor)
+    axis2_up = axis2.upsample(factor=factor)
+    geom_wcs_4 = geom_wcs_1.copy(axes=[axis1_up, axis2_up])
+    m_r_4 = m.reproject_to_geom(geom_wcs_4, preserve_counts=False)
+    for data, idx in m_r_4.iter_by_image_data():
+        ref = int(idx[1] / factor) + 0.5 * int(idx[0] / factor)
+        if np.any(data > 0):
+            assert_allclose(np.nanmean(data[data > 0]), ref)
+
+
+def test_wcsndmap_reproject_allsky_car():
+    geom = WcsGeom.create(binsz=10.0, proj="CAR", frame="icrs")
+    m = WcsNDMap(geom)
+    mask = m.geom.get_coord()[0] > 180 * u.deg
+    m.data = mask.astype(float)
+
+    geom0 = WcsGeom.create(
+        binsz=20, proj="CAR", frame="icrs", skydir=(180.0, 0.0), width=20
+    )
+    expected = np.mean([m.data[0, 0], m.data[0, -1]])  # wrap at 180deg
+
+    m0 = m.reproject_to_geom(geom0)
+    assert_allclose(m0.data[0], expected)
+
+    geom1 = HpxGeom.create(binsz=5.0, frame="icrs")
+    m1 = m.reproject_to_geom(geom1)
+    mask = np.abs(m1.geom.get_coord()[0] - 180) <= 5
+    assert_allclose(np.unique(m1.data[mask])[1], expected)
 
 
 def test_iter_by_image():
@@ -579,3 +785,26 @@ def test_split_by_axis():
     )
     maps = m_4d.split_by_axis("time")
     assert len(maps) == 3
+
+
+def test_rename_axes():
+    time_axis = MapAxis.from_bounds(
+        0,
+        24,
+        nbin=3,
+        unit="hour",
+        name="time",
+    )
+    energy_axis = MapAxis.from_bounds(
+        1, 100, nbin=2, unit="TeV", name="energy", interp="log"
+    )
+    m_4d = Map.create(
+        binsz=1.0, width=(10, 5), frame="galactic", axes=[energy_axis, time_axis]
+    )
+    geom = m_4d.geom.rename_axes("energy", "energy_true")
+    assert m_4d.geom.axes.names == ["energy", "time"]
+    assert geom.axes.names == ["energy_true", "time"]
+
+    new_map = m_4d.rename_axes("energy", "energy_true")
+    assert m_4d.geom.axes.names == ["energy", "time"]
+    assert new_map.geom.axes.names == ["energy_true", "time"]
