@@ -1027,8 +1027,8 @@ class TemplateSpatialModel(SpatialModel):
     Filename : str
         Name of the map file
     copy_data : bool
-        Create a deepcopy of the map data or directly use the original. True by default, can be turned
-        to False to save memory in case of large maps.
+        Create a deepcopy of the map data or directly use the original. True by
+        default, can be turned to False to save memory in case of large maps.
     """
 
     tag = ["TemplateSpatialModel", "template"]
@@ -1192,7 +1192,7 @@ class TemplateSpatialModel(SpatialModel):
         elif os.path.isfile(self.filename) and not overwrite:
             log.warning("Template file already exits, and overwrite is False")
         else:
-            self.map.write(self.filename)
+            self.map.write(self.filename, overwrite=overwrite)
 
     def to_region(self, **kwargs):
         """Model outline from template map boundary (`~regions.RectangleSkyRegion`)."""
