@@ -1,17 +1,18 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Time-dependent models."""
+import logging
 import numpy as np
 import scipy.interpolate
 from astropy import units as u
 from astropy.table import Table
 from astropy.time import Time
 from astropy.utils import lazyproperty
-from gammapy.maps import RegionNDMap, TimeMapAxis
+from gammapy.maps import MapAxis, RegionNDMap, TimeMapAxis
 from gammapy.modeling import Parameter
 from gammapy.utils.random import InverseCDFSampler, get_random_state
 from gammapy.utils.scripts import make_path
 from gammapy.utils.time import time_ref_from_dict
-from .core import ModelBase
+from .core import ModelBase, _build_parameters_from_dict
 
 __all__ = [
     "ConstantTemporalModel",
@@ -22,14 +23,18 @@ __all__ = [
     "LinearTemporalModel",
     "PowerLawTemporalModel",
     "SineTemporalModel",
+    "TemplatePhaseCurveTemporalModel",
     "TemporalModel",
 ]
 
+log = logging.getLogger(__name__)
+
 
 # TODO: make this a small ABC to define a uniform interface.
 class TemporalModel(ModelBase):
     """Temporal model base class.
-    evaluates on  astropy.time.Time objects"""
+
+    Evaluates on  astropy.time.Time objects"""
 
     _type = "temporal"
 
@@ -51,8 +56,7 @@ class TemporalModel(ModelBase):
 
     @staticmethod
     def time_sum(t_min, t_max):
-        """
-        Total time between t_min and t_max
+        """Total time between t_min and t_max
 
         Parameters
         ----------
@@ -69,7 +73,7 @@ class TemporalModel(ModelBase):
         # TODO: this is a work-around for https://github.com/astropy/astropy/issues/10501
         return u.Quantity(np.sum(diff.to_value("day")), "day")
 
-    def plot(self, time_range, ax=None, **kwargs):
+    def plot(self, time_range, ax=None, n_points=100, **kwargs):
         """
         Plot Temporal Model.
 
@@ -79,6 +83,8 @@ class TemporalModel(ModelBase):
             times to plot the model
         ax : `~matplotlib.axes.Axes`, optional
             Axis to plot on
+        n_points : int
+            Number of bins to plot model
         **kwargs : dict
             Keywords forwarded to `~matplotlib.pyplot.errorbar`
 
@@ -89,7 +95,7 @@ class TemporalModel(ModelBase):
         """
         time_min, time_max = time_range
         time_axis = TimeMapAxis.from_time_bounds(
-            time_min=time_min, time_max=time_max, nbin=100
+            time_min=time_min, time_max=time_max, nbin=n_points
         )
 
         m = RegionNDMap.create(region=None, axes=[time_axis])
@@ -136,39 +142,52 @@ class TemporalModel(ModelBase):
             else ontime.unit
         )
 
-        t_stop = ontime.to_value(time_unit)
-
-        # TODO: the separate time unit handling is unfortunate, but the quantity support for np.arange and np.interp
-        #  is still incomplete, refactor once we change to recent numpy and astropy versions
         t_step = t_delta.to_value(time_unit)
-        if hasattr(self, "table"):
-            t = np.arange(0, t_stop, t_step)
+        t_step = (t_step * u.s).to("d")
 
-            pdf = self.evaluate(t)
+        t = Time(np.arange(t_min.mjd, t_max.mjd, t_step.value), format="mjd")
 
-            sampler = InverseCDFSampler(pdf=pdf, random_state=random_state)
-            time_pix = sampler.sample(n_events)[0]
-            time = np.interp(time_pix, np.arange(len(t)), t) * time_unit
+        pdf = self(t)
 
-        else:
-            t_step = (t_step * u.s).to("d")
-
-            t = Time(np.arange(t_min.mjd, t_max.mjd, t_step.value), format="mjd")
-
-            pdf = self(t)
-
-            sampler = InverseCDFSampler(pdf=pdf, random_state=random_state)
-            time_pix = sampler.sample(n_events)[0]
-            time = (
-                np.interp(time_pix, np.arange(len(t)), t.value - min(t.value))
-                * t_step.unit
-            ).to(time_unit)
+        sampler = InverseCDFSampler(pdf=pdf, random_state=random_state)
+        time_pix = sampler.sample(n_events)[0]
+        time = (
+            np.interp(time_pix, np.arange(len(t)), t.value - min(t.value)) * t_step.unit
+        ).to(time_unit)
 
         return t_min + time
 
+    def integral(self, t_min, t_max, oversampling_factor=100, **kwargs):
+        """Evaluate the integrated flux within the given time intervals
+
+        Parameters
+        ----------
+        t_min: `~astropy.time.Time`
+            Start times of observation
+        t_max: `~astropy.time.Time`
+            Stop times of observation
+        oversampling_factor : int
+            Oversampling factor to be used for numerical integration.
+
+        Returns
+        -------
+        norm : float
+            Integrated flux norm on the given time intervals
+        """
+        t_values, steps = np.linspace(
+            t_min.mjd, t_max.mjd, oversampling_factor, retstep=True, axis=-1
+        )
+        times = Time(t_values, format="mjd")
+        values = self(times)
+        integral = np.sum(values, axis=-1) * steps
+        return integral / self.time_sum(t_min, t_max).to_value("d")
+
 
 class ConstantTemporalModel(TemporalModel):
-    """Constant temporal model."""
+    """Constant temporal model.
+
+    For more information see :ref:`constant-temporal-model`.
+    """
 
     tag = ["ConstantTemporalModel", "const"]
 
@@ -250,8 +269,7 @@ class LinearTemporalModel(TemporalModel):
 class ExpDecayTemporalModel(TemporalModel):
     r"""Temporal model with an exponential decay.
 
-    .. math::
-            F(t) = exp(-(t - t_ref)/t0)
+    For more information see :ref:`expdecay-temporal-model`.
 
     Parameters
     ----------
@@ -297,8 +315,7 @@ class ExpDecayTemporalModel(TemporalModel):
 class GaussianTemporalModel(TemporalModel):
     r"""A Gaussian temporal profile
 
-    .. math::
-            F(t) = exp( -0.5 * \frac{ (t - t_{ref})^2 } { \sigma^2 })
+    For more information see :ref:`gaussian-temporal-model`.
 
     Parameters
     ----------
@@ -348,10 +365,7 @@ class GaussianTemporalModel(TemporalModel):
 class GeneralizedGaussianTemporalModel(TemporalModel):
     r"""A generalized Gaussian temporal profile
 
-    .. math::
-            F(t) = exp( - 0.5 * (\frac{ \lvert t - t_{ref} \rvert}{t_rise}) ^ {1 / \eta})   for  t < t_ref
-
-            F(t) = exp( - 0.5 * (\frac{ \lvert t - t_{ref} \rvert}{t_decay}) ^ {1 / \eta})   for  t > t_ref
+    For more information see :ref:`generalized-gaussian-temporal-model`.
 
     Parameters
     ----------
@@ -389,53 +403,20 @@ class GeneralizedGaussianTemporalModel(TemporalModel):
         val = np.where(time < t_ref, val_rise, val_decay)
         return val
 
-    def integral(self, t_min, t_max, **kwargs):
-        """Evaluate the integrated flux within the given time intervals
-
-        Parameters
-        ----------
-        t_min: `~astropy.time.Time`
-            Start times of observation
-        t_max: `~astropy.time.Time`
-            Stop times of observation
-
-        Returns
-        -------
-        norm : float
-            Integrated flux norm on the given time intervals
-        """
-
-        pars = self.parameters
-        t_rise = pars["t_rise"].quantity
-        t_decay = pars["t_decay"].quantity
-        eta = pars["eta"].quantity
-        t_ref = Time(pars["t_ref"].quantity, format="mjd")
-
-        integral = scipy.integrate.quad(
-            self.evaluate, t_min.mjd, t_max.mjd, args=(t_ref.mjd, t_rise, t_decay, eta)
-        )[0]
-        return integral / self.time_sum(t_min, t_max).to_value("d")
-
 
 class LightCurveTemplateTemporalModel(TemporalModel):
     """Temporal light curve model.
 
-    The lightcurve is given as a table with columns ``time`` and ``norm``.
+    The lightcurve is given at specific times (and optionally energies) as a ``norm``
+    It can be serialised either as an astropy table or a `~gammapy.maps.RegionNDMap`
 
     The ``norm`` is supposed to be a unit-less multiplicative factor in the model,
     to be multiplied with a spectral model.
 
-    The model does linear interpolation for times between the given ``(time, norm)`` values.
+    The model does linear interpolation for times between the given ``(time, energy, norm)``
+    values.
 
-    The implementation currently uses `scipy.interpolate. InterpolatedUnivariateSpline`,
-    using degree ``k=1`` to get linear interpolation.
-    This class also contains an ``integral`` method, making the computation of
-    mean fluxes for a given time interval a one-liner.
-
-    Parameters
-    ----------
-    table : `~astropy.table.Table`
-        A table with 'TIME' vs 'NORM'
+    For more information see :ref:`LightCurve-temporal-model`.
 
     Examples
     --------
@@ -449,6 +430,7 @@ class LightCurveTemplateTemporalModel(TemporalModel):
 
     >>> print(light_curve)
     LightCurveTemplateTemporalModel model summary:
+    Reference time: 59000.5 MJD
     Start time: 59000.5 MJD
     End time: 61862.5 MJD
     Norm min: 0.01551196351647377
@@ -457,118 +439,184 @@ class LightCurveTemplateTemporalModel(TemporalModel):
 
     Compute ``norm`` at a given time:
 
-    >>> light_curve.evaluate(60000)
-    array(0.01551196)
+    >>> t = Time(59001.195, format="mjd")
+    >>> light_curve.evaluate(t)
+    array(0.02287888)
 
     Compute mean ``norm`` in a given time interval:
 
     >>> from astropy.time import Time
-    >>> times = Time([60000, 61000], format='mjd')
-    >>> light_curve.integral(times[0], times[1])
-    <Quantity 0.01721725>
+    >>> import astropy.units as u
+    >>> t_r = Time(59000.5, format='mjd')
+    >>> t_min = t_r + [1, 4, 8] * u.d
+    >>> t_max = t_r + [1.5, 6, 9] * u.d
+    >>> light_curve.integral(t_min, t_max)
+    array([0.0074388942, 0.0071144081, 0.0068115544])
     """
 
     tag = ["LightCurveTemplateTemporalModel", "template"]
 
-    def __init__(self, table, filename=None):
-        self.table = table
-        if filename is not None:
-            filename = str(make_path(filename))
-        self.filename = filename
+    _t_ref_default = Time("2000-01-01")
+    t_ref = Parameter("t_ref", _t_ref_default.mjd, unit="day", frozen=False)
+
+    def __init__(self, map, t_ref=None, filename=None):
+
+        if (map.data < 0).any():
+            log.warning("Map has negative values. Check and fix this!")
+
+        if map.geom.has_energy_axis:
+            raise NotImplementedError(
+                "LightCurveTemplateTemporalModel does not"
+                f" support energy axis, got {map.geom.axes.names}"
+            )
+
+        self.map = map.copy()
         super().__init__()
 
+        if t_ref:
+            self.t_ref.value = Time(t_ref, format="mjd").mjd
+
+        self.filename = filename
+
     def __str__(self):
-        norm = self.table["NORM"]
-        return (
-            f"{self.__class__.__name__} model summary:\n"
-            f"Start time: {self._time[0].mjd} MJD\n"
-            f"End time: {self._time[-1].mjd} MJD\n"
-            f"Norm min: {norm.min()}\n"
-            f"Norm max: {norm.max()}\n"
+        start_time = self.t_ref.quantity + self.map.geom.axes["time"].edges[0]
+        end_time = self.t_ref.quantity + self.map.geom.axes["time"].edges[-1]
+        norm_min = np.min(self.map.data)
+        norm_max = np.max(self.map.data)
+
+        prnt = (
+            f"{self.__class__.__name__} model summary:\n "
+            f"Reference time: {self.t_ref.value} MJD \n "
+            f"Start time: {start_time.value} MJD \n "
+            f"End time: {end_time.value} MJD \n "
+            f"Norm min: {norm_min} \n"
+            f"Norm max: {norm_max}"
         )
 
+        return prnt
+
     @classmethod
-    def read(cls, path):
-        """Read lightcurve model table from FITS file.
+    def from_table(cls, table, filename=None):
+        """Create a template model from an astropy table
 
-        TODO: This doesn't read the XML part of the model yet.
+        Parameters
+        ----------
+        table : `~astropy.table.Table`
+            Table containing the template model.
+        filename : str
+            Name of input file
+
+        Returns
+        -------
+        model : `LightCurveTemplateTemporalModel`
+            Light curve template model
         """
-        filename = str(make_path(path))
-        return cls(Table.read(filename), filename=filename)
+        columns = [_.lower() for _ in table.colnames]
+        if "time" not in columns:
+            raise ValueError("A TIME column is necessary")
 
-    def write(self, path=None, overwrite=False):
-        if path is None:
-            path = self.filename
-        if path is None:
-            raise ValueError(f"filename is required for {self.tag}")
-        else:
-            self.filename = str(make_path(path))
-            self.table.write(self.filename, overwrite=overwrite)
-
-    @lazyproperty
-    def _interpolator(self, ext=0):
-        x = self._time.value
-        y = self.table["NORM"].data
-        return scipy.interpolate.InterpolatedUnivariateSpline(x, y, k=1, ext=ext)
-
-    @lazyproperty
-    def _time_ref(self):
-        return time_ref_from_dict(self.table.meta)
-
-    @lazyproperty
-    def _time(self):
-        return self._time_ref + self.table["TIME"].data * getattr(
-            u, self.table.meta["TIMEUNIT"]
+        t_ref = time_ref_from_dict(table.meta)
+        nodes = table["TIME"]
+        time_axis = MapAxis.from_nodes(
+            nodes=nodes, name="time", unit=table.meta["TIMEUNIT"]
+        )
+        axes = [time_axis]
+        m = RegionNDMap.create(
+            region=None, axes=axes, meta=table.meta, data=table["NORM"]
         )
 
-    def evaluate(self, time, ext=0):
-        """Evaluate for a given time.
+        return cls(m, t_ref=t_ref, filename=filename)
+
+    @classmethod
+    def read(cls, filename, format="table"):
+        """Read a template model
 
         Parameters
         ----------
-        time : array_like
-            Time since the ``reference`` time.
-        ext : int or str, optional, default: 0
-            Parameter passed to ~scipy.interpolate.InterpolatedUnivariateSpline
-            Controls the extrapolation mode for GTIs outside the range
-            0 or "extrapolate", return the extrapolated value.
-            1 or "zeros", return 0
-            2 or "raise", raise a ValueError
-            3 or "const", return the boundary value.
-
+        filename : str
+            Name of file to read
+        format : {"table", "map"}
+            Format of the input file.
 
         Returns
         -------
-        norm : array_like
-            Norm at the given times.
+        model : `LightCurveTemplateTemporalModel`
+            Light curve template model
         """
-        return self._interpolator(time, ext=ext)
+        filename = str(make_path(filename))
+        if format == "table":
+            table = Table.read(filename)
+            return cls.from_table(table, filename=filename)
 
-    def integral(self, t_min, t_max):
-        """Evaluate the integrated flux within the given time intervals
+        elif format == "map":
+            m = RegionNDMap.read(filename)
+            t_ref = time_ref_from_dict(m.meta)
+            return cls(m, t_ref=t_ref, filename=filename)
 
-        Parameters
-        ----------
-        t_min: `~astropy.time.Time`
-            Start times of observation
-        t_max: `~astropy.time.Time`
-            Stop times of observation
-        Returns
-        -------
-        norm: The model integrated flux
+        else:
+            raise ValueError(
+                f"Not a valid format: '{format}', choose from: {'table', 'map'}"
+            )
+
+    def to_table(self):
+        """Convert model to an astropy table"""
+        table = Table(
+            data=[self.map.geom.axes["time"].center, self.map.quantity],
+            names=["TIME", "NORM"],
+            meta=self.map.meta,
+        )
+        return table
+
+    def write(self, filename, format="table", overwrite=False):
+        """Write a model to disk as per the specified format
+
+        Parameters:
+            filename : str
+                name of output file
+            format : str, either "table" or "map"
+                if format is table, it is serialised as an astropy Table
+                if map, then it is serialised as a RegionNDMap
+            overwrite : bool
+                Overwrite file on disk if present
         """
 
-        n1 = self._interpolator.antiderivative()(t_max.mjd)
-        n2 = self._interpolator.antiderivative()(t_min.mjd)
-        return u.Quantity(n1 - n2, "day") / self.time_sum(t_min, t_max)
+        if self.filename is None:
+            raise IOError("Missing filename")
+
+        if format == "table":
+            table = self.to_table()
+            table.write(filename, overwrite=overwrite)
+        elif format == "map":
+            self.map.write(filename, overwrite=overwrite)
+        else:
+            raise ValueError("Not a valid format, choose from ['map', 'table']")
+
+    def evaluate(self, time, t_ref=None):
+        """Evaluate the model at given coordinates."""
+
+        if t_ref is None:
+            t_ref = Time(self.t_ref.value, format="mjd")
+
+        t = (time - t_ref).to_value(self.map.geom.axes["time"].unit)
+        coords = {"time": t}
+        val = self.map.interp_by_coord(coords)
+        val = np.clip(val, 0, a_max=None)
+        return u.Quantity(val, self.map.unit, copy=False)
 
     @classmethod
     def from_dict(cls, data):
-        return cls.read(data["temporal"]["filename"])
+        data = data["temporal"]
+        filename = data["filename"]
+        format = data.get("format", "table")
+        return cls.read(filename, format)
 
-    def to_dict(self, full_output=False):
+    def to_dict(self, full_output=False, format="table"):
         """Create dict for YAML serialisation"""
-        return {self._type: {"type": self.tag[0], "filename": self.filename}}
+        data = super().to_dict(full_output)
+        data["temporal"]["filename"] = self.filename
+        data["temporal"]["format"] = format
+        data["temporal"]["unit"] = str(self.map.unit)
+        return data
 
 
 class PowerLawTemporalModel(TemporalModel):
@@ -678,3 +726,237 @@ class SineTemporalModel(TemporalModel):
             - np.sin(omega * (t_min - t_ref).to_value("day"))
         )
         return value / self.time_sum(t_min, t_max)
+
+
+class TemplatePhaseCurveTemporalModel(TemporalModel):
+    """Temporal phase curve model.
+
+    A timing solution is used to compute the phase corresponding to time and
+    a template phase curve is used to determine the associated ``norm``.
+
+    The phasecurve is given as a table with columns ``phase`` and ``norm``.
+
+    The ``norm`` is supposed to be a unit-less multiplicative factor in the model,
+    to be multiplied with a spectral model.
+
+    The model does linear interpolation for times between the given ``(phase, norm)`` values.
+
+    The implementation currently uses `scipy.interpolate. InterpolatedUnivariateSpline`,
+    using degree ``k=1`` to get linear interpolation.
+    This class also contains an ``integral`` method, making the computation of
+    mean fluxes for a given time interval a one-liner.
+
+    Parameters
+    ----------
+    table : `~astropy.table.Table`
+        A table with 'PHASE' vs 'NORM'
+    filename : str
+        The name of the file containing the phase curve
+    t_ref : `~astropy.units.Quantity`
+        The reference time in mjd
+    phi_ref : `~astropy.units.Quantity`
+        The phase at reference time. Default is 0.
+    f0 : `~astropy.units.Quantity`
+        The frequency at t_ref in s-1
+    f1 : `~astropy.units.Quantity`
+        The frequency derivative at t_ref in s-2. Default is 0 s-2.
+    f2 : `~astropy.units.Quantity`
+        The frequency second derivative at t_ref in s-3. Default is 0 s-3.
+    """
+
+    tag = ["TemplatePhaseCurveTemporalModel", "template-phase"]
+    _t_ref_default = Time(48442.5, format="mjd")
+    _phi_ref_default = 0
+    _f0_default = 29.946923 * u.s**-1
+    _f1_default = 0 * u.s**-2
+    _f2_default = 0 * u.s**-3
+
+    t_ref = Parameter("t_ref", _t_ref_default.mjd, unit="day", frozen=True)
+    phi_ref = Parameter("phi_ref", _phi_ref_default, unit="", frozen=True)
+    f0 = Parameter("f0", _f0_default, frozen=True)
+    f1 = Parameter("f1", _f1_default, frozen=True)
+    f2 = Parameter("f2", _f2_default, frozen=True)
+
+    def __init__(self, table, filename=None, **kwargs):
+        self.table = table
+        if filename is not None:
+            filename = str(make_path(filename))
+        self.filename = filename
+        super().__init__(**kwargs)
+
+    @classmethod
+    def read(
+        cls,
+        path,
+        t_ref=_t_ref_default.mjd * u.d,
+        phi_ref=_phi_ref_default,
+        f0=_f0_default,
+        f1=_f1_default,
+        f2=_f2_default,
+    ):
+        """Read phasecurve model table from FITS file.
+
+        Beware : this does **not** read parameters.
+        They will be set to defaults.
+
+        Parameters
+        ----------
+        path : str or `~pathlib.Path`
+            filename with path
+        """
+        filename = str(make_path(path))
+        return cls(
+            Table.read(filename),
+            filename=filename,
+            t_ref=t_ref,
+            phi_ref=phi_ref,
+            f0=f0,
+            f1=f1,
+            f2=f2,
+        )
+
+    @staticmethod
+    def _time_to_phase(time, t_ref, phi_ref, f0, f1, f2):
+        """Convert time to phase given timing solution parameters.
+
+        Parameters
+        ----------
+        time : `~astropy.units.Quantity`
+            The time at which to compute the phase
+        t_ref : `~astropy.units.Quantity`
+            The reference time in mjd.
+        phi_ref : `~astropy.units.Quantity`
+            The phase at reference time. Default is 0.
+        f0 : `~astropy.units.Quantity`
+            The frequency at t_ref in s-1
+        f1 : `~astropy.units.Quantity`
+            The frequency derivative at t_ref in s-2.
+        f2 : `~astropy.units.Quantity`
+            The frequency second derivative at t_ref in s-3.
+
+        Returns
+        -------
+        phase : float
+            Phase.
+        period_number : int
+            Number of period since t_ref.
+        """
+        delta_t = time - t_ref
+        phase = (
+            phi_ref + delta_t * (f0 + delta_t / 2.0 * (f1 + delta_t / 3 * f2))
+        ).to_value("")
+
+        period_number = np.floor(phase)
+        phase -= period_number
+        return phase, period_number
+
+    def write(self, path=None, overwrite=False):
+        if path is None:
+            path = self.filename
+        if path is None:
+            raise ValueError(f"filename is required for {self.tag}")
+        else:
+            self.filename = str(make_path(path))
+            self.table.write(self.filename, overwrite=overwrite)
+
+    @lazyproperty
+    def _interpolator(self):
+        x = self.table["PHASE"].data
+        y = self.table["NORM"].data
+
+        return scipy.interpolate.InterpolatedUnivariateSpline(
+            x, y, k=1, ext=2, bbox=[0.0, 1.0]
+        )
+
+    def evaluate(self, time, t_ref, phi_ref, f0, f1, f2):
+        phase, _ = self._time_to_phase(time, t_ref, phi_ref, f0, f1, f2)
+        return self._interpolator(phase)
+
+    def integral(self, t_min, t_max):
+        """Evaluate the integrated flux within the given time intervals
+
+        Parameters
+        ----------
+        t_min: `~astropy.time.Time`
+            Start times of observation
+        t_max: `~astropy.time.Time`
+            Stop times of observation
+        Returns
+        -------
+        norm: The model integrated flux
+        """
+        kwargs = {par.name: par.quantity for par in self.parameters}
+        ph_min, n_min = self._time_to_phase(t_min.mjd * u.d, **kwargs)
+        ph_max, n_max = self._time_to_phase(t_max.mjd * u.d, **kwargs)
+
+        # here we assume that the frequency does not change during the integration boundaries
+        delta_t = (t_min.mjd - self.t_ref.value) * u.d
+        frequency = self.f0.quantity + delta_t * (
+            self.f1.quantity + delta_t * self.f2.quantity / 2
+        )
+
+        # Compute integral of one phase
+        phase_integral = self._interpolator.antiderivative()(
+            1
+        ) - self._interpolator.antiderivative()(0)
+        # Multiply by the total number of phases
+        phase_integral *= n_max - n_min - 1
+
+        # Compute integrals before first full phase and after the last full phase
+        end_integral = self._interpolator.antiderivative()(
+            ph_max
+        ) - self._interpolator.antiderivative()(0)
+        start_integral = self._interpolator.antiderivative()(
+            1
+        ) - self._interpolator.antiderivative()(ph_min)
+
+        # Divide by Jacobian (here we neglect variations of frequency during the integration period)
+        total = (phase_integral + start_integral + end_integral) / frequency
+        # Normalize by total integration time
+        integral_norm = total / self.time_sum(t_min, t_max)
+
+        return integral_norm.to("")
+
+    @classmethod
+    def from_dict(cls, data):
+        params = _build_parameters_from_dict(
+            data["temporal"]["parameters"], cls.default_parameters
+        )
+        filename = data["temporal"]["filename"]
+        kwargs = {par.name: par for par in params}
+        return cls.read(filename, **kwargs)
+
+    def to_dict(self, full_output=False):
+        """Create dict for YAML serialisation"""
+        model_dict = super().to_dict()
+        model_dict["temporal"]["filename"] = self.filename
+        return model_dict
+
+    def plot_phasogram(self, ax=None, n_points=100, **kwargs):
+        """
+        Plot phasogram of the phase model.
+
+        Parameters
+        ----------
+        ax : `~matplotlib.axes.Axes`, optional
+            Axis to plot on
+        n_points : int
+            Number of bins to plot model
+        **kwargs : dict
+            Keywords forwarded to `~matplotlib.pyplot.errorbar`
+
+        Returns
+        -------
+        ax : `~matplotlib.axes.Axes`, optional
+            axis
+        """
+        phase_axis = MapAxis.from_bounds(0.0, 1, nbin=n_points, name="Phase", unit="")
+
+        m = RegionNDMap.create(region=None, axes=[phase_axis])
+        kwargs.setdefault("marker", "None")
+        kwargs.setdefault("ls", "-")
+        kwargs.setdefault("xerr", None)
+        m.quantity = self._interpolator(phase_axis.center)
+        ax = m.plot(ax=ax, **kwargs)
+        ax.set_ylabel("Norm / A.U.")
+        return ax
