@@ -5,6 +5,7 @@ import numpy as np
 from numpy.testing import assert_allclose
 import astropy.units as u
 from astropy.table import Table
+import matplotlib.pyplot as plt
 from gammapy.maps import MapAxis, RegionNDMap
 from gammapy.modeling.models import (
     SPECTRAL_MODEL_REGISTRY,
@@ -641,6 +642,12 @@ def test_template_spectral_model_single_value():
 
     assert_allclose(result.data, 1e-12)
 
+    model.norm.value = 0.5
+    data = model.to_dict()
+    assert_allclose(data["spectral"]["parameters"][0]["value"], 0.5)
+    model2 = TemplateSpectralModel.from_dict(data)
+    assert model2.to_dict() == data
+
 
 def test_template_spectral_model_compound():
     energy = [1.00e06, 1.25e06, 1.58e06, 1.99e06] * u.MeV
@@ -856,17 +863,20 @@ class TestNaimaModel:
             "energy_bounds": [10 * u.GeV, 80 * u.TeV],
             "sed_type": "e2dnde",
         }
-        model.plot(label="IC (total)", **opts)
+        _, ax = plt.subplots()
+        model.plot(label="IC (total)", ax=ax, **opts)
+
         for seed, ls in zip(["CMB", "FIR"], ["-", "--"]):
             model = NaimaSpectralModel(radiative_model, seed=seed, distance=1.5 * u.kpc)
             model.plot(label=f"IC ({seed})", ls=ls, color="gray", **opts)
 
         skymodel = SkyModel(model)
         # fail if cache is on :
+        _, ax = plt.subplots()
         skymodel.spectral_model.plot(
-            energy_bounds=[10 * u.GeV, 80 * u.TeV], energy_power=2
+            energy_bounds=[10 * u.GeV, 80 * u.TeV], energy_power=2, ax=ax
         )
-        assert radiative_model._memoize == False
+        assert not radiative_model._memoize
 
 
 class TestSpectralModelErrorPropagation:
