@@ -219,7 +219,7 @@ def test_stat_profile():
     dataset.models.parameters["x"].scan_n_values = 3
     result = fit.stat_profile(datasets=[dataset], parameter="x")
 
-    assert_allclose(result["x_scan"], [0, 2, 4], atol=1e-7)
+    assert_allclose(result["test.model.x_scan"], [0, 2, 4], atol=1e-7)
     assert_allclose(result["stat_scan"], [4, 0, 4], atol=1e-7)
     assert len(result["fit_results"]) == 0
 
@@ -236,7 +236,7 @@ def test_stat_profile_reoptimize():
     dataset.models.parameters["x"].scan_n_values = 3
     result = fit.stat_profile(datasets=[dataset], parameter="x", reoptimize=True)
 
-    assert_allclose(result["x_scan"], [0, 2, 4], atol=1e-7)
+    assert_allclose(result["test.model.x_scan"], [0, 2, 4], atol=1e-7)
     assert_allclose(result["stat_scan"], [4, 0, 4], atol=1e-7)
     assert_allclose(
         result["fit_results"][0].total_stat, result["stat_scan"][0], atol=1e-7
@@ -255,8 +255,8 @@ def test_stat_surface():
     dataset.models.parameters["y"].scan_values = y_values
     result = fit.stat_surface(datasets=[dataset], x="x", y="y")
 
-    assert_allclose(result["x_scan"], x_values, atol=1e-7)
-    assert_allclose(result["y_scan"], y_values, atol=1e-7)
+    assert_allclose(result["test.model.x_scan"], x_values, atol=1e-7)
+    assert_allclose(result["test.model.y_scan"], y_values, atol=1e-7)
     expected_stat = [
         [1.0001e04, 1.0000e00, 1.0001e04],
         [1.0000e04, 0.0000e00, 1.0000e04],
@@ -284,8 +284,8 @@ def test_stat_surface_reoptimize():
 
     result = fit.stat_surface(datasets=[dataset], x="x", y="y", reoptimize=True)
 
-    assert_allclose(result["x_scan"], x_values, atol=1e-7)
-    assert_allclose(result["y_scan"], y_values, atol=1e-7)
+    assert_allclose(result["test.model.x_scan"], x_values, atol=1e-7)
+    assert_allclose(result["test.model.y_scan"], y_values, atol=1e-7)
     expected_stat = [
         [1.0001e04, 1.0000e00, 1.0001e04],
         [1.0000e04, 0.0000e00, 1.0000e04],
@@ -307,14 +307,15 @@ def test_stat_contour():
 
     assert result["success"]
 
-    x = result["y"]
-    assert_allclose(len(x), 10)
+    x = result["test.model.y"]
+    assert len(x) in [10, 11]  # Behavior changed after iminuit>=2.13
     assert_allclose(x[0], 299, rtol=1e-5)
-    assert_allclose(x[-1], 299.133975, rtol=1e-5)
-    y = result["z"]
-    assert_allclose(len(y), 10)
+    assert_allclose(x[9], 299.133975, rtol=1e-5)
+    y = result["test.model.z"]
+    assert len(x) == len(y)
+    assert len(y) in [10, 11]
     assert_allclose(y[0], 0.04, rtol=1e-5)
-    assert_allclose(y[-1], 0.54, rtol=1e-5)
+    assert_allclose(y[9], 0.54, rtol=1e-5)
 
     # Check that original value state wasn't changed
     assert_allclose(dataset.models.parameters["y"].value, 300)
