@@ -3,12 +3,12 @@ import pytest
 from numpy.testing import assert_allclose
 from gammapy.modeling import Parameter
 from gammapy.modeling.iminuit import confidence_iminuit, optimize_iminuit
-from gammapy.modeling.models import Model, Models
+from gammapy.modeling.models import ModelBase, Models
 
 pytest.importorskip("iminuit")
 
 
-class MyModel(Model):
+class MyModel(ModelBase):
     x = Parameter("x", 2.1, error=0.2)
     y = Parameter("y", 3.1, scale=1e5, error=3e4)
     z = Parameter("z", 4.1, scale=1e-5, error=4e-6)
@@ -94,16 +94,12 @@ def test_iminuit_limits():
     assert_allclose(pars["y"].value, 301000, rtol=1e-3)
 
     # Check that minuit sees the limit factors correctly
-    states = minuit.get_param_states()
-    assert not states[0]["has_limits"]
+    params = minuit.init_params
 
-    y = states[1]
-    assert y["has_limits"]
-    assert_allclose(y["lower_limit"], 3.01)
-
-    # The next assert can be added when we no longer test on iminuit 1.2
-    # See https://github.com/gammapy/gammapy/pull/1771
-    # assert states[1]["upper_limit"] is None
+    assert not params["x"].has_limits
+    assert params["par_001_y"].has_limits
+    assert_allclose(params["par_001_y"].lower_limit, 3.01)
+    assert params["par_001_y"].upper_limit is None
 
 
 def test_opts():
@@ -127,7 +123,9 @@ def test_iminuit_confidence():
     par = pars["x"]
     par.min, par.max = 0, 10
 
-    result = confidence_iminuit(minuit=minuit, parameters=pars, parameter=par, sigma=1)
+    result = confidence_iminuit(
+        function=ds.fcn, parameters=pars, parameter=par, sigma=1, reoptimize=True
+    )
 
     assert result["success"]
 
