@@ -7,7 +7,6 @@ for developers and the test runner from including it in test collection.
 import logging
 import warnings
 import click
-from gammapy import test
 
 log = logging.getLogger(__name__)
 
@@ -17,12 +16,6 @@ def cli_check():
     """Run checks for Gammapy"""
 
 
-@cli_check.command("runtests")
-def cli_check_runtests():
-    """Run Gammapy tests"""
-    test(verbose=True)
-
-
 @cli_check.command("logging")
 def cli_check_logging():
     """Check logging"""
@@ -30,3 +23,4 @@ def cli_check_logging():
     log.info("this is log.info() output")
     log.warning("this is log.warning() output")
     warnings.warn("this is warnings.warn() output")
+    print("this is stdout output")
