@@ -2,25 +2,70 @@
 """Command line tool to download datasets and notebooks"""
 import logging
 import tarfile
+import zipfile
 from pathlib import Path
+from urllib.parse import urlparse
+from astropy.utils import lazyproperty
 import click
 from gammapy import __version__
 
 log = logging.getLogger(__name__)
 
 BUNDLESIZE = 152  # in MB
-ENVS_BASE_URL = "https://gammapy.org/download/install"
-NBTAR_BASE_URL = "https://docs.gammapy.org"
-TAR_DATASETS = "https://github.com/gammapy/gammapy-data/tarball/master"
+GAMMAPY_BASE_URL = "https://gammapy.org/download/"
+
+RELEASE = __version__
+
+if "dev" in __version__:
+    RELEASE = "dev"
+
+
+class DownloadIndex:
+    """Download index"""
+
+    _notebooks_key = "notebooks"
+    _datasets_key = "datasets"
+    _environment_key = "conda-environment"
+    _index_json = "index.json"
+
+    def __init__(self, release=RELEASE):
+        self.release = release
+
+    @lazyproperty
+    def index(self):
+        """Index for a given release"""
+        import requests
+
+        response = requests.get(GAMMAPY_BASE_URL + self._index_json)
+        data = response.json()
+
+        if self.release not in data:
+            raise ValueError(
+                f"Download not available for release {self.release}, "
+                f"choose from: {list(data.keys())}"
+            )
+
+        return data[self.release]
+
+    @property
+    def notebooks_url(self):
+        """Notebooks URL"""
+        return self.index[self._notebooks_key]
+
+    @property
+    def environment_url(self):
+        """Environment URL"""
+        return self.index[self._environment_key]
+
+    @property
+    def datasets_url(self):
+        """Datasets URL"""
+        return self.index[self._datasets_key]
 
 
 def progress_download(source, destination):
-    try:
-        import requests
-        from tqdm import tqdm
-    except ImportError:
-        log.error("To use gammapy download install the tqdm and requests packages")
-        return
+    import requests
+    from tqdm import tqdm
 
     destination.parent.mkdir(parents=True, exist_ok=True)
     with requests.get(source, stream=True) as r:
@@ -45,7 +90,7 @@ def members(tf):
     root_folder = list_members[0].name
     for member in list_members:
         if member.path.startswith(root_folder):
-            member.path = member.path[len(root_folder) + 1 :]
+            member.path = member.path[len(root_folder) + 1 :]  # noqa: E203
             yield member
 
 
@@ -75,7 +120,12 @@ def show_info_datasets(outfolder):
 
 
 @click.command(name="notebooks")
-@click.option("--release", required=True, help="Number of stable release - ex: 0.18.2)")
+@click.option(
+    "--release",
+    default=RELEASE,
+    help="Number of stable release - ex: 0.18.2)",
+    show_default=True,
+)
 @click.option(
     "--out",
     default="gammapy-notebooks",
@@ -84,36 +134,53 @@ def show_info_datasets(outfolder):
 )
 def cli_download_notebooks(release, out):
     """Download notebooks"""
-    localfolder = Path(out) / release
-    url_file_env = f"{ENVS_BASE_URL}/gammapy-{release}-environment.yml"
-    if release == "dev":
-        url_file_env = "https://raw.githubusercontent.com/gammapy/gammapy/master/environment-dev.yml"
+    index = DownloadIndex(release=release)
 
-    yaml_destination_file = localfolder / f"gammapy-{release}-environment.yml"
-    progress_download(url_file_env, yaml_destination_file)
-    url_tar_notebooks = f"{NBTAR_BASE_URL}/{release}/_downloads/notebooks-{release}.tar"
-    tar_destination_file = localfolder / f"notebooks_{release}.tar"
-    progress_download(url_tar_notebooks, tar_destination_file)
-    my_tar = tarfile.open(tar_destination_file)
-    my_tar.extractall(localfolder)
-    my_tar.close()
-    Path(tar_destination_file).unlink()
-    show_info_notebooks(localfolder, release)
+    path = Path(out) / index.release
+
+    filename = path / f"gammapy-{index.release}-environment.yml"
+    progress_download(index.environment_url, filename)
+
+    url_path = urlparse(index.notebooks_url).path
+    filename_destination = path / Path(url_path).name
+    progress_download(index.notebooks_url, filename_destination)
+
+    if "zip" in index.notebooks_url:
+        archive = zipfile.ZipFile(filename_destination, "r")
+    else:
+        archive = tarfile.open(filename_destination)
+
+    with archive as ref:
+        ref.extractall(path)
+
+    # delete file
+    filename_destination.unlink()
+
+    show_info_notebooks(path, release)
 
 
 @click.command(name="datasets")
+@click.option(
+    "--release",
+    default=RELEASE,
+    help="Number of stable release - ex: 0.18.2)",
+    show_default=True,
+)
 @click.option(
     "--out",
     default="gammapy-datasets",
     help="Destination folder.",
     show_default=True,
 )
-def cli_download_datasets(out):
+def cli_download_datasets(release, out):
     """Download datasets"""
-    localfolder = Path(out)
-    log.info(f"Downloading datasets from {TAR_DATASETS}")
+    index = DownloadIndex(release=release)
+
+    localfolder = Path(out) / index.release
+    log.info(f"Downloading datasets from {index.datasets_url}")
     tar_destination_file = localfolder / "datasets.tar.gz"
-    progress_download(TAR_DATASETS, tar_destination_file)
+    progress_download(index.datasets_url, tar_destination_file)
+
     log.info(f"Extracting {tar_destination_file}")
     extract_bundle(tar_destination_file, localfolder)
     Path(tar_destination_file).unlink()
