@@ -29,12 +29,12 @@ def test_cash_basic(n_on, mu_bkg, result):
 
 
 values = [
-    (1, 2, [-0.69829, 1.35767667]),
-    (5, 1, [-1.915916, 2.581106]),
-    (10, 5, [-2.838105, 3.504033]),
-    (100, 23, [-9.669482, 10.336074]),
-    (1, 20, [-0.69829, 1.357677]),
-    (5 * ref_array, 1 * ref_array, [-1.915916, 2.581106]),
+    (1, 2, [0.69829, 1.35767667]),
+    (5, 1, [1.915916, 2.581106]),
+    (10, 5, [2.838105, 3.504033]),
+    (100, 23, [9.669482, 10.336074]),
+    (1, 20, [0.69829, 1.357677]),
+    (5 * ref_array, 1 * ref_array, [1.915916, 2.581106]),
 ]
 
 
@@ -132,12 +132,12 @@ def test_wstat_with_musig(n_on, n_off, alpha, mu_sig, result):
 
 
 values = [
-    (1, 2, 1, [-1.942465, 1.762589]),
-    (5, 1, 1, [-2.310459, 2.718807]),
-    (10, 5, 0.3, [-2.932472, 3.55926]),
-    (10, 23, 0.1, [-2.884366, 3.533279]),
-    (1, 20, 1.0, [-4.897018, 4.299083]),
-    (5 * ref_array, 1 * ref_array, 1 * ref_array, [-2.310459, 2.718807]),
+    (1, 2, 1, [1.942465, 1.762589]),
+    (5, 1, 1, [2.310459, 2.718807]),
+    (10, 5, 0.3, [2.932472, 3.55926]),
+    (10, 23, 0.1, [2.884366, 3.533279]),
+    (1, 20, 1.0, [4.897018, 4.299083]),
+    (5 * ref_array, 1 * ref_array, 1 * ref_array, [2.310459, 2.718807]),
 ]
 
 
