@@ -7,12 +7,19 @@ from astropy.convolution import Gaussian2DKernel
 
 __all__ = [
     "array_stats_str",
+    "round_up_to_even",
+    "round_up_to_odd",
     "shape_2N",
     "shape_divisible_by",
     "symmetric_crop_pad_width",
 ]
 
 
+def is_power2(n):
+    """Check if an integer is a power of 2."""
+    return (n > 0) & ((n & (n - 1)) == 0)
+
+
 def array_stats_str(x, label=""):
     """Make a string summarising some stats for an array.
 
@@ -61,7 +68,7 @@ def shape_2N(shape, N=3):
         New shape extended to integers divisible by 2^N
     """
     shape = np.array(shape)
-    new_shape = shape + (2 ** N - np.mod(shape, 2 ** N))
+    new_shape = shape + (2**N - np.mod(shape, 2**N))
     return tuple(new_shape)
 
 
@@ -86,6 +93,38 @@ def shape_divisible_by(shape, factor):
     return tuple(new_shape)
 
 
+def round_up_to_odd(f):
+    """Round float to odd integer
+
+    Parameters
+    ----------
+    f : float
+        Float value
+
+    Returns
+    -------
+    int : int
+        Odd integer
+    """
+    return (np.ceil(f) // 2 * 2 + 1).astype(int)
+
+
+def round_up_to_even(f):
+    """Round float to even integer
+
+    Parameters
+    ----------
+    f : float
+        Float value
+
+    Returns
+    -------
+    int : int
+        Odd integer
+    """
+    return (np.ceil(f + 1) // 2 * 2).astype(int)
+
+
 def symmetric_crop_pad_width(shape, new_shape):
     """
     Compute symmetric crop or pad width.
@@ -145,4 +184,4 @@ def scale_cube(data, kernels):
     cube : `~numpy.ndarray`
         Array of the shape (len(kernels), data.shape)
     """
-    return np.dstack(list([_fftconvolve_wrap(kernel, data) for kernel in kernels]))
+    return np.dstack([_fftconvolve_wrap(kernel, data) for kernel in kernels])
