@@ -17,7 +17,6 @@ Here's some good resources with working examples:
 - https://github.com/bokeh/bokeh/tree/master/bokeh/sphinxext
 """
 import os
-from configparser import ConfigParser
 from pathlib import Path
 from docutils.parsers.rst import Directive
 from docutils.parsers.rst.directives import register_directive
@@ -34,13 +33,6 @@ except KeyError:
     HAS_GP_DATA = False
 
 log = logging.getLogger(__name__)
-PATH_CFG = Path(__file__).resolve().parent / ".." / ".."
-
-# fetch params from setup.cfg
-conf = ConfigParser()
-conf.read(PATH_CFG / "setup.cfg")
-build_docs_cfg = dict(conf.items("build_docs"))
-PATH_NBS = build_docs_cfg["downloadable-notebooks"]
 
 
 class AccordionHeader(Directive):
@@ -54,7 +46,8 @@ class AccordionHeader(Directive):
         raw = f"""
             <div id="accordion" class="shadow tutorial-accordion">
         <div class="card tutorial-card">
-            <div class="card-header collapsed card-link" data-toggle="collapse" data-target="#{self.options["id"]}">
+            <div class="card-header collapsed card-link" data-toggle="collapse"
+             data-target="#{self.options["id"]}">
                 <div class="d-flex flex-row tutorial-card-header-1">
                     <div class="d-flex flex-row tutorial-card-header-2">
                         <button class="btn btn-dark btn-sm"></button>
@@ -168,6 +161,29 @@ class DocsImage(Image):
         return super().run()
 
 
+class SubstitutionCodeBlock(CodeBlock):
+    """
+    Similar to CodeBlock but replaces placeholders with variables.
+    """
+
+    def run(self):
+        """
+        Replace placeholders with given variables.
+        """
+        app = self.state.document.settings.env.app
+        new_content = []
+        self.content = self.content
+        existing_content = self.content
+        for item in existing_content:
+            for pair in app.config.substitutions:
+                original, replacement = pair
+                item = item.replace(original, replacement)
+            new_content.append(item)
+
+        self.content = new_content
+        return list(CodeBlock.run(self))
+
+
 def gammapy_sphinx_ext_activate():
     if HAS_GP_DATA:
         log.info(f"*** Found GAMMAPY_DATA = {gammapy_data_path}")
