@@ -32,9 +32,12 @@ def trapz_loglog(y, x, axis=-1):
     energy_min, energy_max = x[:-1], x[1:]
     vals_energy_min, vals_energy_max = y[:-1], y[1:]
 
-    # log scale has the build-in zero clipping
+    # log scale has the built-in zero clipping
     log = LogScale()
-    index = -log(vals_energy_min / vals_energy_max) / log(energy_min / energy_max)
+
+    with np.errstate(invalid="ignore", divide="ignore"):
+        index = -log(vals_energy_min / vals_energy_max) / log(energy_min / energy_max)
+
     index[np.isnan(index)] = np.inf
 
     return pl.evaluate_integral(
