@@ -9,7 +9,6 @@ import yaml
 
 __all__ = [
     "get_images_paths",
-    "get_notebooks_paths",
     "make_path",
     "read_yaml",
     "recursive_merge_dicts",
@@ -20,19 +19,6 @@ PATH_DOCS = Path(__file__).resolve().parent / ".." / ".." / "docs"
 SKIP = ["_static", "_build", "_checkpoints", "docs/user-guide/model-gallery/"]
 
 
-def get_notebooks_paths(folder=PATH_DOCS):
-    """Generator yields a Path for each notebook.
-
-    Parameters
-    ----------
-    folder : str
-        Folder where to search
-    """
-    for i in Path(folder).rglob("*.ipynb"):
-        if not any(s in str(i) for s in SKIP):
-            yield i.resolve()
-
-
 def get_images_paths(folder=PATH_DOCS):
     """Generator yields a Path for each image used in notebook.
 
@@ -93,10 +79,17 @@ def write_yaml(dictionary, filename, logger=None, sort_keys=True):
 
 
 def make_name(name=None):
+    """Make a dataset name"""
     if name is None:
-        return urlsafe_b64encode(codecs.decode(uuid4().hex, "hex")).decode()[:8]
-    else:
-        return name
+        name = urlsafe_b64encode(codecs.decode(uuid4().hex, "hex")).decode()[:8]
+
+    if not isinstance(name, str):
+        raise ValueError(
+            "Name argument must be a string, "
+            f"got '{name}', which is of type '{type(name)}'"
+        )
+
+    return name
 
 
 def make_path(path):
