@@ -1,17 +1,42 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Table helper utilities."""
+import numpy as np
 from astropy.table import Table
 from astropy.units import Quantity
 from .units import standardise_unit
 
 __all__ = [
+    "hstack_columns",
+    "table_from_row_data",
+    "table_row_to_dict",
     "table_standardise_units_copy",
     "table_standardise_units_inplace",
-    "table_row_to_dict",
-    "table_from_row_data",
 ]
 
 
+def hstack_columns(table, table_other):
+    """Stack the column data horizontally
+
+    Parameters
+    ----------
+    table : `~astropy.table.Table`
+        Input table
+    table_other : `~astropy.table.Table`
+        Other input table
+
+    Returns
+    -------
+    stacked : `~astropy.table.Table`
+        Stacked table
+    """
+    stacked = Table()
+
+    for column in table.colnames:
+        data = np.hstack([table[column].data[0], table_other[column].data[0]])
+        stacked[column] = data[np.newaxis, :]
+    return stacked
+
+
 def table_standardise_units_copy(table):
     """Standardise units for all columns in a table in a copy.
 
@@ -34,8 +59,7 @@ def table_standardise_units_copy(table):
 
 
 def table_standardise_units_inplace(table):
-    """Standardise units for all columns in a table in place.
-    """
+    """Standardise units for all columns in a table in place."""
     for column in table.columns.values():
         if column.unit:
             column.unit = standardise_unit(column.unit)
@@ -78,7 +102,12 @@ def table_from_row_data(rows, **kwargs):
         List of row data (each row a dict)
     """
     table = Table(**kwargs)
+
+    if len(rows) == 0:
+        return table
+
     colnames = list(rows[0].keys())
+
     for name in colnames:
         coldata = [_[name] for _ in rows]
         if isinstance(rows[0][name], Quantity):
