@@ -1,19 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from gammapy.utils.scripts import (
-    get_images_paths,
-    get_notebooks_paths,
-    recursive_merge_dicts,
-)
+import pytest
+from gammapy.utils.scripts import get_images_paths, recursive_merge_dicts
 
 
+@pytest.mark.xfail
 def test_get_images_paths():
     assert any("images" in str(p) for p in get_images_paths())
 
 
-def test_get_notebooks_paths():
-    assert any("maps.ipynb" in str(p) for p in get_notebooks_paths())
-
-
 def test_recursive_merge_dicts():
     old = dict(a=42, b=dict(c=43, e=44))
     update = dict(d=99, b=dict(g=98, c=50))
